<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:fct="localFunctions"
                xmlns:ntdb="PLACEHOLDER"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <!--PHASES-->
   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <!--XSD TYPES FOR XSLT2-->
   <!--KEYS AND FUNCTIONS-->
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:parseDate"
                 as="xs:string">
      <xsl:param name="input"/>
      <xsl:choose>
         <xsl:when test="$input castable as xs:date">
            <xsl:value-of select="$input"/>
         </xsl:when>
         <xsl:when test="$input castable as xs:string">
            <xsl:choose>
               <xsl:when test="string-length($input)=8">
                  <xsl:variable name="year" as="xs:string" select="substring($input,1,4)"/>
                  <xsl:variable name="month" as="xs:string" select="substring($input,5,2)"/>
                  <xsl:variable name="day" as="xs:string" select="substring($input,7,2)"/>
                  <xsl:value-of select="string-join(($year,$month,$day),'-')"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="''"/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="''"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:notLessThanDate"
                 as="xs:boolean">
      <xsl:param name="firstDate"/>
      <xsl:param name="secondDate"/>
      <xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
      <xsl:variable name="secondDateMod" select="fct:parseDate($secondDate)"/>
      <xsl:choose>
         <xsl:when test="($firstDateMod castable as xs:date) and ($secondDateMod castable as xs:date) ">
            <xsl:value-of select="not(xs:date($firstDateMod) &lt; xs:date($secondDateMod))"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="true()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:notPirorToNextCalendarDay"
                 as="xs:boolean">
      <xsl:param name="firstDate"/>
      <xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
      <xsl:choose>
         <xsl:when test="$firstDateMod castable as xs:date">
            <xsl:value-of select="xs:date($firstDateMod) &gt; xs:date(current-dateTime() + xs:dayTimeDuration('PT24H'))"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:notEqualDate"
                 as="xs:boolean">
      <xsl:param name="firstDate"/>
      <xsl:param name="secondDate"/>
      <xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
      <xsl:variable name="secondDateMod" select="fct:parseDate($secondDate)"/>
      <xsl:choose>
         <xsl:when test="($firstDateMod castable as xs:date) and ($secondDateMod castable as xs:date)">
            <xsl:value-of select="not(xs:date($firstDateMod) = xs:date($secondDateMod))"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="true()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:padTime"
                 as="xs:time">
      <xsl:param name="input" as="xs:string"/>
      <xsl:choose>
         <xsl:when test="$input castable as xs:time">
            <xsl:value-of select="$input"/>
         </xsl:when>
         <xsl:when test="string-length($input)=5">
            <xsl:value-of select="string-join(($input,'00'), ':')"/>
         </xsl:when>
         <xsl:when test="string-length($input)=6">
            <xsl:variable name="hours" as="xs:string" select="substring($input,1,2)"/>
            <xsl:variable name="minutes" as="xs:string" select="substring($input,3,2)"/>
            <xsl:variable name="seconds" as="xs:string" select="substring($input,5,2)"/>
            <xsl:value-of select="string-join(($hours,$minutes,$seconds),':')"/>
         </xsl:when>
         <xsl:when test="string-length($input)=4">
            <xsl:variable name="hours" as="xs:string" select="substring($input,1,2)"/>
            <xsl:variable name="minutes" as="xs:string" select="substring($input,3,2)"/>
            <xsl:variable name="seconds" as="xs:string" select="'00'"/>
            <xsl:value-of select="string-join(($hours,$minutes,$seconds),':')"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="''"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:notLessThanTime"
                 as="xs:boolean">
      <xsl:param name="firstTime" as="xs:string?"/>
      <xsl:param name="secondTime" as="xs:string?"/>
      <xsl:choose>
         <xsl:when test="$firstTime = '' or not($firstTime)">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:when test="$secondTime = '' or not($secondTime)">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:when test="not(xs:time(fct:padTime($firstTime)) &lt; xs:time(fct:padTime($secondTime)))">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:notEqualTime"
                 as="xs:boolean">
      <xsl:param name="firstTime" as="xs:string?"/>
      <xsl:param name="secondTime" as="xs:string?"/>
      <xsl:choose>
         <xsl:when test="$firstTime = '' or not($firstTime)">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:when test="$secondTime = '' or not($secondTime)">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:when test="not(xs:time(fct:padTime($firstTime)) = xs:time(fct:padTime($secondTime)))">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:matches"
                 as="xs:boolean">
      <xsl:param name="data" as="xs:string"/>
      <xsl:param name="regex" as="xs:string"/>
      <xsl:choose>
         <xsl:when test="matches($data,$regex)">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:durationParse"
                 as="xs:integer">
      <xsl:param name="startDate"/>
      <xsl:param name="endDate"/>
      <xsl:param name="type" as="xs:string"/>
      <xsl:variable name="startDateMod" select="fct:parseDate($startDate)"/>
      <xsl:variable name="endDateMod" select="fct:parseDate($endDate)"/>
      <xsl:choose>
         <xsl:when test="($startDateMod castable as xs:date) and ($endDateMod castable as xs:date)">
            <xsl:variable name="startDateModYear" select="year-from-date(xs:date($startDateMod))"/>
            <xsl:variable name="startDateModMonth"
                          select="month-from-date(xs:date($startDateMod))"/>
            <xsl:variable name="startDateModDay" select="day-from-date(xs:date($startDateMod))"/>
            <xsl:variable name="endDateModYear" select="year-from-date(xs:date($endDateMod))"/>
            <xsl:variable name="endDateModMonth" select="month-from-date(xs:date($endDateMod))"/>
            <xsl:variable name="endDateModDay" select="day-from-date(xs:date($endDateMod))"/>
            <xsl:choose>
               <xsl:when test="$type = '5'">
                  <xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('PT1M'))"/>
               </xsl:when>
               <xsl:when test="$type = '1'">
                  <xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('PT1H'))"/>
               </xsl:when>
               <xsl:when test="$type = '2'">
                  <xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('P1D'))"/>
               </xsl:when>
               <xsl:when test="$type = '3'">
                  <xsl:choose>
                     <xsl:when test="$endDateModDay &lt; $startDateModDay">
                        <xsl:value-of select="$endDateModMonth - $startDateModMonth - 1"/>
                     </xsl:when>
                     <xsl:otherwise>
                        <xsl:value-of select="($endDateModMonth - $startDateModMonth) + 12 * ($endDateModYear - $startDateModYear)"/>
                     </xsl:otherwise>
                  </xsl:choose>
               </xsl:when>
               <xsl:when test="$type = '4'">
                  <xsl:choose>
                     <xsl:when test="$endDateModMonth &lt; $startDateModMonth">
                        <xsl:value-of select="$endDateModYear - $startDateModYear - 1"/>
                     </xsl:when>
                     <xsl:when test="($endDateModMonth = $startDateModMonth) and ($endDateModDay &lt; $startDateModDay)">
                        <xsl:value-of select="$endDateModYear - $startDateModYear - 1"/>
                     </xsl:when>
                     <xsl:otherwise>
                        <xsl:value-of select="$endDateModYear - $startDateModYear"/>
                     </xsl:otherwise>
                  </xsl:choose>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="-1"/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="-1"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fct:getYear"
                 as="xs:integer">
      <xsl:param name="date"/>
      <xsl:variable name="dateMod">
         <xsl:choose>
            <xsl:when test="$date castable as xs:date">
               <xsl:value-of select="$date"/>
            </xsl:when>
            <xsl:when test="$date castable as xs:string">
               <xsl:value-of select="fct:parseDate($date)"/>
            </xsl:when>
            <xsl:otherwise>
               <xsl:value-of select="$date"/>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:variable>
      <xsl:choose>
         <xsl:when test="$dateMod castable as xs:date">
            <xsl:value-of select="year-from-date($dateMod)"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="0"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <!--DEFAULT RULES-->
   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>
   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>
   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title="NTDB ISO Schematron file"
                              schemaVersion="2020">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="localFunctions" prefix="fct"/>
         <svrl:ns-prefix-in-attribute-values uri="PLACEHOLDER" prefix="ntdb"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HomeZip</xsl:attribute>
            <xsl:attribute name="name">HomeZip Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M16"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HomeCountry</xsl:attribute>
            <xsl:attribute name="name">IncidentCountry Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M17"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HomeState</xsl:attribute>
            <xsl:attribute name="name">IncidentState Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M18"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HomeCounty</xsl:attribute>
            <xsl:attribute name="name">IncidentCounty Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M19"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HomeCity</xsl:attribute>
            <xsl:attribute name="name">HomeCity Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M20"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HomeResidence</xsl:attribute>
            <xsl:attribute name="name">HomeResidence Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M21"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">DateOfBirth_Rules</xsl:attribute>
            <xsl:attribute name="name">DateOfBirth Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M22"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Age</xsl:attribute>
            <xsl:attribute name="name">Age Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M23"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AgeUnits_Rules</xsl:attribute>
            <xsl:attribute name="name">DateOfBirth Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M24"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Race</xsl:attribute>
            <xsl:attribute name="name">Race Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M25"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Ethnicity</xsl:attribute>
            <xsl:attribute name="name">Ethnicity Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M26"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Sex</xsl:attribute>
            <xsl:attribute name="name">Sex Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M27"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">IncidentDate</xsl:attribute>
            <xsl:attribute name="name">IncidentDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M28"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">IncidentTime_Rules</xsl:attribute>
            <xsl:attribute name="name">IncidentDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M29"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">WorkRelated_Rules</xsl:attribute>
            <xsl:attribute name="name">WorkRelated Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M30"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PatientsOccupationalIndustry_Rules</xsl:attribute>
            <xsl:attribute name="name">PatientsOccupationalIndustry Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M31"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PatientsOccupation</xsl:attribute>
            <xsl:attribute name="name">PatientsOccupation Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M32"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PrimaryECodeIcd10_Rules_2</xsl:attribute>
            <xsl:attribute name="name">PrimaryECodeIcd10 Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M33"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PlaceOfInjuryCode</xsl:attribute>
            <xsl:attribute name="name">PlaceOfInjuryCode Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M34"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AdditionalECodeIcd10</xsl:attribute>
            <xsl:attribute name="name">AdditionalECodeIcd10 Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M35"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">InjuryZip</xsl:attribute>
            <xsl:attribute name="name">InjuryZip Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M36"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">IncidentCountry</xsl:attribute>
            <xsl:attribute name="name">IncidentCounty Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M37"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">IncidentState</xsl:attribute>
            <xsl:attribute name="name">IncidentState Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M38"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">IncidentCounty</xsl:attribute>
            <xsl:attribute name="name">IncidentCounty Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M39"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">IncidentCity</xsl:attribute>
            <xsl:attribute name="name">IncidentCity Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M40"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">ProtectiveDevice</xsl:attribute>
            <xsl:attribute name="name">ProtectiveDevice Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M41"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">ChildSpecificRestraint</xsl:attribute>
            <xsl:attribute name="name">ChildSpecificRestraint Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M42"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AirbagDeployment</xsl:attribute>
            <xsl:attribute name="name">AirbagDeployment Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M43"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AbuseReport</xsl:attribute>
            <xsl:attribute name="name">AbuseReport Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M44"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AbuseInvestigation</xsl:attribute>
            <xsl:attribute name="name">AbuseInvestigation Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M45"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">CaregiverAtDischarge</xsl:attribute>
            <xsl:attribute name="name">CaregiverAtDischarge Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M46"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsNotifyDate</xsl:attribute>
            <xsl:attribute name="name">EmsNotifyDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M47"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsNotifyTime</xsl:attribute>
            <xsl:attribute name="name">EmsNotifyTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M48"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsArrivalDate</xsl:attribute>
            <xsl:attribute name="name">EmsArrivalDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M49"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsArrivalTime</xsl:attribute>
            <xsl:attribute name="name">EmsArrivalTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M50"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsLeftDate</xsl:attribute>
            <xsl:attribute name="name">EmsLeftDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M51"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsLeftTime</xsl:attribute>
            <xsl:attribute name="name">EmsLeftTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M52"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TransportMode</xsl:attribute>
            <xsl:attribute name="name">TransportMode Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M53"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">OtherTransportMode</xsl:attribute>
            <xsl:attribute name="name">OtherTransportMode Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M54"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsSbp</xsl:attribute>
            <xsl:attribute name="name">EmsSbp Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M55"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsPulseRate</xsl:attribute>
            <xsl:attribute name="name">EmsSbp Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M56"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsRespiratoryRate</xsl:attribute>
            <xsl:attribute name="name">EMS RespiratoryRate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M57"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsPulseOximetry</xsl:attribute>
            <xsl:attribute name="name">EmsPulseOximetry Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M58"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsGcsEye</xsl:attribute>
            <xsl:attribute name="name">EmsGcsEye Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M59"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsGcsVerbal</xsl:attribute>
            <xsl:attribute name="name">EmsGcsVerbal Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M60"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsGcsMotor</xsl:attribute>
            <xsl:attribute name="name">EmsGcsMotor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M61"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsTotalGcs</xsl:attribute>
            <xsl:attribute name="name">EmsTotalGcs Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M62"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsGcs40Eye</xsl:attribute>
            <xsl:attribute name="name">EmsGcs40Eye Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M63"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsGcs40Verbal</xsl:attribute>
            <xsl:attribute name="name">EmsGcs40Motor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M64"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmsGcs40Motor</xsl:attribute>
            <xsl:attribute name="name">EmsGcs40Motor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M65"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">InterFacilityTransfer</xsl:attribute>
            <xsl:attribute name="name">InterFacilityTransfer Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M66"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TraumaCenterCriterion</xsl:attribute>
            <xsl:attribute name="name">TraumaCenterCriterion Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M67"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">VehicularPedestrianOther</xsl:attribute>
            <xsl:attribute name="name">VehicularPedestrianOther Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M68"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PrehospitalCardiacArrest</xsl:attribute>
            <xsl:attribute name="name">PrehospitalCardiacArrest Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M69"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalArrivalDate</xsl:attribute>
            <xsl:attribute name="name">HospitalArrivalDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M70"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalArrivalTime</xsl:attribute>
            <xsl:attribute name="name">HospitalArrivalTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M71"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Sbp</xsl:attribute>
            <xsl:attribute name="name">Sbp Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M72"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PulseRate</xsl:attribute>
            <xsl:attribute name="name">PulseRate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M73"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Temperature</xsl:attribute>
            <xsl:attribute name="name">Temperature Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M74"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">RespiratoryRate</xsl:attribute>
            <xsl:attribute name="name">RespiratoryRate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M75"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">RespiratoryAssistance</xsl:attribute>
            <xsl:attribute name="name">RespiratoryAssistance Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M76"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PulseOximetry</xsl:attribute>
            <xsl:attribute name="name">PulseOximetry Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M77"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">SupplementalOxygen</xsl:attribute>
            <xsl:attribute name="name">SupplementalOxygen Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M78"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">GcsEye</xsl:attribute>
            <xsl:attribute name="name">GcsEye Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M79"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">GcsVerbal</xsl:attribute>
            <xsl:attribute name="name">GcsVerbal Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M80"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">GcsMotor</xsl:attribute>
            <xsl:attribute name="name">GcsMotor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M81"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TotalGcs</xsl:attribute>
            <xsl:attribute name="name">TotalGcs Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M82"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">GcsQualifier</xsl:attribute>
            <xsl:attribute name="name">GcsQualifier Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M83"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Gcs40Eye</xsl:attribute>
            <xsl:attribute name="name">Gcs40Eye Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M84"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Gcs40Verbal</xsl:attribute>
            <xsl:attribute name="name">Gcs40Motor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M85"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Gcs40Motor</xsl:attribute>
            <xsl:attribute name="name">Gcs40Motor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M86"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Height</xsl:attribute>
            <xsl:attribute name="name">Height Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M87"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Weight</xsl:attribute>
            <xsl:attribute name="name">Weight Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M88"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">DrugScreen</xsl:attribute>
            <xsl:attribute name="name">DrugScreen Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M89"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AlcoholScreen</xsl:attribute>
            <xsl:attribute name="name">AlcoholScreen Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M90"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AlcoholScreenResult</xsl:attribute>
            <xsl:attribute name="name">AlcoholScreenResult Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M91"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EdDischargeDisposition</xsl:attribute>
            <xsl:attribute name="name">EdDischargeDisposition Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M92"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">DeathInEd</xsl:attribute>
            <xsl:attribute name="name">DeathInEd Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M93"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EdDischargeOrdersWrittenDate</xsl:attribute>
            <xsl:attribute name="name">EdDischargeOrdersWrittenDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M94"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EdDischargeOrdersWrittenTime</xsl:attribute>
            <xsl:attribute name="name">EdDischargeOrdersWrittenTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M95"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalProcedureIcd10</xsl:attribute>
            <xsl:attribute name="name">HospitalProcedureIcd10 Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M96"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalProcedureStartDate</xsl:attribute>
            <xsl:attribute name="name">HospitalProcedureStartDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M97"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalProcedureStartTime</xsl:attribute>
            <xsl:attribute name="name">HospitalProcedureStartDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M98"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">ComorbidCondition</xsl:attribute>
            <xsl:attribute name="name">ComorbidCondition Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M99"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">DiagnosisIcd10</xsl:attribute>
            <xsl:attribute name="name">DiagnosisIcd10 Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M100"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AisPredot</xsl:attribute>
            <xsl:attribute name="name">AisPredot Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M101"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AisSeverity</xsl:attribute>
            <xsl:attribute name="name">AisSeverity Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M102"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AisVersion</xsl:attribute>
            <xsl:attribute name="name">AisVersion Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M103"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TotalIcuLos</xsl:attribute>
            <xsl:attribute name="name">TotalIcuLos Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M104"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TotalVentDays</xsl:attribute>
            <xsl:attribute name="name">TotalVentDays Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M105"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalDischargeOrdersWrittenDate</xsl:attribute>
            <xsl:attribute name="name">HospitalDischargeOrdersWrittenDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M106"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalDischargeOrdersWrittenTime</xsl:attribute>
            <xsl:attribute name="name">HospitalDischargeOrdersWrittenDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M107"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalDischargeDisposition</xsl:attribute>
            <xsl:attribute name="name">HospitalDischargeDisposition Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M108"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">PrimaryMethodPayment</xsl:attribute>
            <xsl:attribute name="name">PrimaryMethodPayment Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M109"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HospitalComplication</xsl:attribute>
            <xsl:attribute name="name">HospitalComplication Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M110"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">NationalProviderIdentifier</xsl:attribute>
            <xsl:attribute name="name">NationalProviderIdentifier Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M111"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiHighestTotalGcs</xsl:attribute>
            <xsl:attribute name="name">TbiHighestTotalGcs Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M112"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiGcsMotor</xsl:attribute>
            <xsl:attribute name="name">TbiGcsMotor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M113"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiGcsQualifier</xsl:attribute>
            <xsl:attribute name="name">TbiGcsQualifier Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M114"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiGcs40Motor</xsl:attribute>
            <xsl:attribute name="name">TbiGcs40Motor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M115"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiPupillaryResponse</xsl:attribute>
            <xsl:attribute name="name">TbiPupillaryResponse Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M116"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiMidlineShift</xsl:attribute>
            <xsl:attribute name="name">TbiMidlineShift Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M117"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiCerebralMonitor</xsl:attribute>
            <xsl:attribute name="name">TbiCerebralMonitor Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M118"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiCerebralMonitorDate</xsl:attribute>
            <xsl:attribute name="name">TbiCerebralMonitorDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M119"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TbiCerebralMonitorTime</xsl:attribute>
            <xsl:attribute name="name">TbiCerebralMonitorTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M120"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">VteProphylaxisType</xsl:attribute>
            <xsl:attribute name="name">VteProphylaxisType Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M121"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">VteProphylaxisDate</xsl:attribute>
            <xsl:attribute name="name">VteProphylaxisDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M122"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">VteProphylaxisTime</xsl:attribute>
            <xsl:attribute name="name">VteProphylaxisTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M123"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TransfusionBlood4Hours</xsl:attribute>
            <xsl:attribute name="name">TransfusionBlood4Hours Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M124"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">WholeBlood4Hours</xsl:attribute>
            <xsl:attribute name="name">WholeBlood4Hours Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M125"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TransfusionPlasma4Hours</xsl:attribute>
            <xsl:attribute name="name">TransfusionPlasma4Hours Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M126"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">TransfusionPlatelets4Hours</xsl:attribute>
            <xsl:attribute name="name">TransfusionPlatelets4Hours Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M127"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Cryoprecipitate4Hours</xsl:attribute>
            <xsl:attribute name="name">Cryoprecipitate4Hours Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M128"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">LowestSbp</xsl:attribute>
            <xsl:attribute name="name">LowestSbp Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M129"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">Angiography</xsl:attribute>
            <xsl:attribute name="name">Angiography Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M130"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">EmbolizationSite</xsl:attribute>
            <xsl:attribute name="name">EmbolizationSite Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M131"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AngiographyDate</xsl:attribute>
            <xsl:attribute name="name">AngiographyDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M132"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AngiographyTime</xsl:attribute>
            <xsl:attribute name="name">AngiographyTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M133"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HemorrhageControlSurgeryType</xsl:attribute>
            <xsl:attribute name="name">HemorrhageControlSurgeryType Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M134"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HemorrhageControlSurgeryDate</xsl:attribute>
            <xsl:attribute name="name">HemorrhageControlSurgeryDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M135"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">HemorrhageControlSurgeryTime</xsl:attribute>
            <xsl:attribute name="name">HemorrhageControlSurgeryTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M136"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">WithdrawalOfCare</xsl:attribute>
            <xsl:attribute name="name">WithdrawalOfCare Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M137"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">WithdrawalOfCareDate</xsl:attribute>
            <xsl:attribute name="name">WithdrawalOfCareDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M138"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">WithdrawalOfCareTime</xsl:attribute>
            <xsl:attribute name="name">WithdrawalOfCareTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M139"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AntibioticTherapy</xsl:attribute>
            <xsl:attribute name="name">AntibioticTherapy Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M140"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AntibioticTherapyDate</xsl:attribute>
            <xsl:attribute name="name">AntibioticTherapyDate Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M141"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">AntibioticTherapyTime</xsl:attribute>
            <xsl:attribute name="name">AntibioticTherapyTime Assertions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M142"/>
      </svrl:schematron-output>
   </xsl:template>
   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">NTDB ISO Schematron file</svrl:text>
   <xsl:param name="ntdbElements" select="()"/>
   <xsl:param name="ntdbElementsMissing" select="''"/>
   <!--PATTERN HomeZipHomeZip Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HomeZip Assertions</svrl:text>
   <!--RULE HomeZip_self_rules-->
   <xsl:template match="HomeZip" priority="1000" mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HomeZip"
                       id="HomeZip_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0002_HomeZip</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0002: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <!--PATTERN HomeCountryIncidentCountry Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentCountry Assertions</svrl:text>
   <!--RULE HomeCountry_self_rules-->
   <xsl:template match="HomeCountry" priority="1000" mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HomeCountry"
                       id="HomeCountry_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0102_HomeCountry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">0104_HomeCountry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0104: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="homeZip" select="../HomeZip !='' or ../HomeZip[@biu]=('1', '2')"/>
      <xsl:variable name="ntdbElements" select=".,../InjuryZip"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu = '2') or not($homeZip)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@biu = '2') or not($homeZip)">
               <xsl:attribute name="id">0105_HomeCountry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0105: Field cannot be "Not Known/Not Recorded" when Home Zip/Postal Code is not "Not Applicable" or "Not Known/Not Recorded"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <!--PATTERN HomeStateIncidentState Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentState Assertions</svrl:text>
   <!--RULE HomeState_self_rule-->
   <xsl:template match="HomeState" priority="1000" mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HomeState"
                       id="HomeState_self_rule"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())">
               <xsl:attribute name="id">0202_HomeState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0202: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())">
               <xsl:attribute name="id">0204_HomeState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0204: Field must be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeZip != '') then(@biu=('1')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeZip != '') then(@biu=('1')) else(true())">
               <xsl:attribute name="id">0205_HomeState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0205: Field must be Not Applicable when patient's homeZip/postcode is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <!--PATTERN HomeCountyIncidentCounty Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentCounty Assertions</svrl:text>
   <!--RULE HomeCounty_self_rules-->
   <xsl:template match="HomeCounty" priority="1000" mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HomeCounty"
                       id="HomeCounty_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())">
               <xsl:attribute name="id">0302_HomeCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0302: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())">
               <xsl:attribute name="id">0304_HomeCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0304: Field must be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeZip != '') then(@biu=('1')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeZip != '') then(@biu=('1')) else(true())">
               <xsl:attribute name="id">0305_HomeCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0305: Field must be Not Applicable when patient's homeZip/postcode is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M19"/>
   <xsl:template match="@*|node()" priority="-2" mode="M19">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <!--PATTERN HomeCityHomeCity Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HomeCity Assertions</svrl:text>
   <!--RULE HomeCity_self_rules-->
   <xsl:template match="HomeCity" priority="1000" mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HomeCity"
                       id="HomeCity_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())">
               <xsl:attribute name="id">0402_HomeCity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0402: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())">
               <xsl:attribute name="id">0404_HomeCity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0404: Field must be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeZip != '') then(@biu=('1')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeZip != '') then(@biu=('1')) else(true())">
               <xsl:attribute name="id">0405_HomeCity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0405: Field must be Not Applicable when patient's homeZip/postcode is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M20"/>
   <xsl:template match="@*|node()" priority="-2" mode="M20">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <!--PATTERN HomeResidenceHomeResidence Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HomeResidence Assertions</svrl:text>
   <!--RULE HomeResidence_self_rules-->
   <xsl:template match="HomeResidence" priority="1000" mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HomeResidence"
                       id="HomeResidence_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0502_HomeResidence</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0502: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1','2')) then(every $element in ./../../item/HomeResidence satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1','2')) then(every $element in ./../../item/HomeResidence satisfies $element='') else(true())">
               <xsl:attribute name="id">0503_HomeResidence</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0503: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M21"/>
   <xsl:template match="@*|node()" priority="-2" mode="M21">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <!--PATTERN DateOfBirth_RulesDateOfBirth Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">DateOfBirth Assertions</svrl:text>
   <!--RULE DateOfBirth_self_rules-->
   <xsl:template match="DateOfBirth" priority="1000" mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="DateOfBirth"
                       id="DateOfBirth_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0603_DateOfBirth</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0603: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../IncidentDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../IncidentDate, .)">
               <xsl:attribute name="id">0609_DateOfBirth</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0609: Date of Birth is later than Injury Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">0610_DateOfBirth</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0610: Date of Birth is later than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">0611_DateOfBirth</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>		
			0611: Date of Birth is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". = '' or ../IncidentDate = '' or (120 &gt; fct:durationParse(., ../IncidentDate, '4'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or ../IncidentDate = '' or (120 &gt; fct:durationParse(., ../IncidentDate, '4'))">
               <xsl:attribute name="id">0612_DateOfBirth</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0612: Date of Birth + 120 years must be less than Injury Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">0613_DateOfBirth</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0613: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M22"/>
   <xsl:template match="@*|node()" priority="-2" mode="M22">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <!--PATTERN AgeAge Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Age Assertions</svrl:text>
   <!--RULE Age_self_rules-->
   <xsl:template match="Age" priority="1000" mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Age"
                       id="Age_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0703_Age</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0703: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="units" select="../AgeUnits"/>
      <xsl:variable name="ntdbElements" select=".,../AgeUnits"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or $units='' or ($units='5' and . &lt;= 60) or ($units='1' and . &lt;= 24)        or ($units='2' and . &lt;= 30) or ($units='3' and . &lt;= 12) or ($units='4' and . &lt;= 120)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or $units='' or ($units='5' and . &lt;= 60) or ($units='1' and . &lt;= 24) or ($units='2' and . &lt;= 30) or ($units='3' and . &lt;= 12) or ($units='4' and . &lt;= 120)">
               <xsl:attribute name="id">0705_Age</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0705: Age is greater than expected for the Age Units specified. Age should not exceed 60 minutes, 24 hours, 30 days, 24 months, or 120 years. Please verify this is correct.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../AgeUnits/@biu='2') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../AgeUnits/@biu='2') then(@biu='2') else(true())">
               <xsl:attribute name="id">0708_Age</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0708: Field must be Not Known/Not Recorded when Age Units is Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../DateOfBirth != '') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../DateOfBirth != '') then(@biu='1') else(true())">
               <xsl:attribute name="id">0709_Age</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0709: Field must be Not Applicable if date of birth if reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M23"/>
   <xsl:template match="@*|node()" priority="-2" mode="M23">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <!--PATTERN AgeUnits_RulesDateOfBirth Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">DateOfBirth Assertions</svrl:text>
   <!--RULE AgeUnits_self_rules-->
   <xsl:template match="AgeUnits" priority="1000" mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AgeUnits"
                       id="AgeUnits_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0803_AgeUnits</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0803: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Age/@biu='2') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Age/@biu='2') then(@biu='2') else(true())">
               <xsl:attribute name="id">0806_AgeUnits</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0806: Field must be Not Known/Not Recorded when Age is Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../DateOfBirth != '') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../DateOfBirth != '') then(@biu='1') else(true())">
               <xsl:attribute name="id">0809_Age</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0809: Field must be Not Applicable if date of birth if reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M24"/>
   <xsl:template match="@*|node()" priority="-2" mode="M24">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <!--PATTERN RaceRace Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Race Assertions</svrl:text>
   <!--RULE Race_self_rules-->
   <xsl:template match="Race" priority="1000" mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Race"
                       id="Race_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">0902_Race</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0902: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../../../HomeCountry = 'US') then(not(@biu='1')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../../../HomeCountry = 'US') then(not(@biu='1')) else(true())">
               <xsl:attribute name="id">0903_Race</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0903: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1', '2')) then(every $element in ./../../item/Race satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1', '2')) then(every $element in ./../../item/Race satisfies $element='') else(true())">
               <xsl:attribute name="id">0905_Race</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			0905: If Race is reported, neither Not Applicable nor Not Known/NotRecorded can also be reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M25"/>
   <xsl:template match="@*|node()" priority="-2" mode="M25">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <!--PATTERN EthnicityEthnicity Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Ethnicity Assertions</svrl:text>
   <!--RULE Ethnicity_self_rules-->
   <xsl:template match="Ethnicity" priority="1000" mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Ethnicity"
                       id="Ethnicity_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1002_Ethnicity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1002: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HomeCountry = 'US') then(not(@biu='1')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HomeCountry = 'US') then(not(@biu='1')) else(true())">
               <xsl:attribute name="id">1003_Ethnicity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1003: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M26"/>
   <xsl:template match="@*|node()" priority="-2" mode="M26">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <!--PATTERN SexSex Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Sex Assertions</svrl:text>
   <!--RULE Sex_self_rules-->
   <xsl:template match="Sex" priority="1000" mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Sex"
                       id="Sex_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1102_Sex</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">1103_Sex</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1103: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M27"/>
   <xsl:template match="@*|node()" priority="-2" mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <!--PATTERN IncidentDateIncidentDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentDate Assertions</svrl:text>
   <!--RULE IncidentDate_self_rules-->
   <xsl:template match="IncidentDate" priority="1000" mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="IncidentDate"
                       id="IncidentDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1203_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1203: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">1204_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1204: Injury Incident Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EmsNotifyDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EmsNotifyDate, .)">
               <xsl:attribute name="id">1205_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1205: Injury Incident Date is later than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EmsArrivalDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EmsArrivalDate, .)">
               <xsl:attribute name="id">1206_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1206: Injury Incident Date is later than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EmsLeftDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EmsLeftDate, .)">
               <xsl:attribute name="id">1207_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1207: Injury Incident Date is later than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalArrivalDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalArrivalDate, .)">
               <xsl:attribute name="id">1208_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1208: Injury Incident Date is later than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">1209_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1209: Injury Incident Date is later than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">1210_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1210: Injury Incident Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">1211_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1211: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:durationParse(../HospitalArrivalDate, ., '2') &lt; 14"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:durationParse(../HospitalArrivalDate, ., '2') &lt; 14">
               <xsl:attribute name="id">1212_IncidentDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1212: Injury Incident Date is greater than 14 days earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M28"/>
   <xsl:template match="@*|node()" priority="-2" mode="M28">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <!--PATTERN IncidentTime_RulesIncidentDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentDate Assertions</svrl:text>
   <!--RULE IncidentTime_self_rules-->
   <xsl:template match="IncidentTime" priority="1000" mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="IncidentTime"
                       id="IncidentTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1303_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1303: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../IncidentDate, ../EmsNotifyDate) or fct:notLessThanTime(../EmsNotifyTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../IncidentDate, ../EmsNotifyDate) or fct:notLessThanTime(../EmsNotifyTime, .)">
               <xsl:attribute name="id">1304_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1304: Injury Incident Time is later than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../IncidentDate, ../EmsArrivalDate) or fct:notLessThanTime(../EmsArrivalTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../IncidentDate, ../EmsArrivalDate) or fct:notLessThanTime(../EmsArrivalTime, .)">
               <xsl:attribute name="id">1305_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1305: Injury Incident Time is later than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../IncidentDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../IncidentDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)">
               <xsl:attribute name="id">1306_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1306: Injury Incident Time is later than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../IncidentDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../IncidentDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
               <xsl:attribute name="id">1307_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1307: Injury Incident Time is later than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../IncidentDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../IncidentDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">1308_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1308: Injury Incident Time is later than ED Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../IncidentDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../IncidentDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">1309_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
	        1309: Injury Incident Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">1310_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1310: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M29"/>
   <xsl:template match="@*|node()" priority="-2" mode="M29">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <!--PATTERN WorkRelated_RulesWorkRelated Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">WorkRelated Assertions</svrl:text>
   <!--RULE WorkRelated_self_rules-->
   <xsl:template match="WorkRelated" priority="1000" mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="WorkRelated"
                       id="WorkRelated_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1402_WorkRelated</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1402: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">1407_WorkRelated</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1407: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M30"/>
   <xsl:template match="@*|node()" priority="-2" mode="M30">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <!--PATTERN PatientsOccupationalIndustry_RulesPatientsOccupationalIndustry Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PatientsOccupationalIndustry Assertions</svrl:text>
   <!--RULE PatientsOccupationalIndustry_self_rules-->
   <xsl:template match="PatientsOccupationalIndustry" priority="1000" mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PatientsOccupationalIndustry"
                       id="PatientsOccupationalIndustry_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1504_PatientsOccupationalIndustry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1504: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../WorkRelated = '1') then (not(@biu='1')) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../WorkRelated = '1') then (not(@biu='1')) else (true())">
               <xsl:attribute name="id">1505_PatientsOccupationalIndustry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1505: If Work-Related is Yes, Patient's Occupational Industry cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../WorkRelated = '2') then (@biu='1') else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../WorkRelated = '2') then (@biu='1') else (true())">
               <xsl:attribute name="id">1506_PatientsOccupationalIndustry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1506: If Work-Related is No, Patient's Occupational Industry must be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M31"/>
   <xsl:template match="@*|node()" priority="-2" mode="M31">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <!--PATTERN PatientsOccupationPatientsOccupation Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PatientsOccupation Assertions</svrl:text>
   <!--RULE PatientsOccupation_self_rules-->
   <xsl:template match="PatientsOccupation" priority="1000" mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PatientsOccupation"
                       id="PatientsOccupation_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">1604_PatientsOccupation</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1604: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../WorkRelated = '1') then (not(@biu='1')) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../WorkRelated = '1') then (not(@biu='1')) else (true())">
               <xsl:attribute name="id">1605_PatientsOccupation</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1605: If Work-Related is Yes, Patient's Occupation cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../WorkRelated = '2') then (@biu='1') else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../WorkRelated = '2') then (@biu='1') else (true())">
               <xsl:attribute name="id">1606_PatientsOccupation</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			1606: Not Applicable must be reported if Work-Related is No
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M32"/>
   <xsl:template match="@*|node()" priority="-2" mode="M32">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <!--PATTERN PrimaryECodeIcd10_Rules_2PrimaryECodeIcd10 Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PrimaryECodeIcd10 Assertions</svrl:text>
   <!--RULE PrimaryECodeIcd10_self_rules-->
   <xsl:template match="PrimaryECodeIcd10" priority="1000" mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PrimaryECodeIcd10"
                       id="PrimaryECodeIcd10_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8902_PrimaryECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8902: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <xsl:variable name="value" select="."/>
      <xsl:variable name="test"
                    select="if(matches($value,&#34;Y92\.[A-Z,0-9]{1,3}&#34;)) then false() else true()"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="$test"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$test">
               <xsl:attribute name="id">8904_PrimaryECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8904: Should not be Y92.X/Y92.XX/Y92.XXX (where X is A-Z or 0-9)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <xsl:variable name="value" select="."/>
      <xsl:variable name="test"
                    select="if(matches($value,&#34;Y93\.[A-Z,0-9]{1,2}&#34;)) then false() else true()"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="$test"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$test">
               <xsl:attribute name="id">8905_PrimaryECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8905: ICD-10 External Cause Code should not be Y93.X/Y93.XX (where X is A-Z or 0-9)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">8907_PrimaryECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8907: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M33"/>
   <xsl:template match="@*|node()" priority="-2" mode="M33">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <!--PATTERN PlaceOfInjuryCodePlaceOfInjuryCode Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PlaceOfInjuryCode Assertions</svrl:text>
   <!--RULE PlaceOfInjuryCode_self_rules-->
   <xsl:template match="PlaceOfInjuryCode" priority="1000" mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PlaceOfInjuryCode"
                       id="PlaceOfInjuryCode_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9002_PlaceOfInjuryCode</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9002: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <xsl:variable name="value" select="."/>
      <xsl:variable name="test"
                    select="if(matches($value,&#34;Y92\.[A-H,J-N,P-Z,0-9]{1,3}&#34;)) then true() else false()"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="$test or . = ''"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$test or . = ''">
               <xsl:attribute name="id">9003_PlaceOfInjuryCode</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9003: Place of Injury code should be Y92.X/Y92.XX/Y92.XXX (where X is A-Z [excluding I,O] or 0-9) (ICD-10 CM only)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">9006_PlaceOfInjuryCode</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9006: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M34"/>
   <xsl:template match="@*|node()" priority="-2" mode="M34">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <!--PATTERN AdditionalECodeIcd10AdditionalECodeIcd10 Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AdditionalECodeIcd10 Assertions</svrl:text>
   <!--RULE AdditionalECodeIcd10_self_rules-->
   <xsl:template match="AdditionalECodeIcd10" priority="1000" mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AdditionalECodeIcd10"
                       id="AdditionalECodeIcd10_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". != ../../PrimaryECodeIcd10 or . != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != ../../PrimaryECodeIcd10 or . != ''">
               <xsl:attribute name="id">9102_AdditionalECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9102: Additional External Cause Code ICD-10 should not be equal to Primary External Cause Code ICD-10
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9103_AdditionalECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9103: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(. = ('T74','T76'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(. = ('T74','T76'))">
               <xsl:attribute name="id">9105_AdditionalECodeIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9105:  ICD-10 T74 and T76 codes cannot be submitted as Additional External Cause Codes
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M35"/>
   <xsl:template match="@*|node()" priority="-2" mode="M35">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <!--PATTERN InjuryZipInjuryZip Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">InjuryZip Assertions</svrl:text>
   <!--RULE InjuryZip_self_rules-->
   <xsl:template match="InjuryZip" priority="1000" mode="M36">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="InjuryZip"
                       id="InjuryZip_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2002_InjuryZip_not_blank</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2002: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2006_InjuryZip_not_blank</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2006: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M36"/>
   <xsl:template match="@*|node()" priority="-2" mode="M36">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>
   <!--PATTERN IncidentCountryIncidentCounty Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentCounty Assertions</svrl:text>
   <!--RULE IncidentCountry_self_rules-->
   <xsl:template match="IncidentCountry" priority="1000" mode="M37">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="IncidentCountry"
                       id="IncidentCountry_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2102_IncidentCountry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">2104_IncidentCountry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2104: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('2')) or not(../IncidentZip='' or ../InjuryZip[@biu]=('1', '2'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@biu=('2')) or not(../IncidentZip='' or ../InjuryZip[@biu]=('1', '2'))">
               <xsl:attribute name="id">2105_IncidentCountry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2105: Field cannot be Not Known/Not Recorded when Incident Location ZIP/Postal Code is not "Not Known/Not Recorded"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M37"/>
   <xsl:template match="@*|node()" priority="-2" mode="M37">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>
   <!--PATTERN IncidentStateIncidentState Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentState Assertions</svrl:text>
   <!--RULE IncidentState_self_rule-->
   <xsl:template match="IncidentState" priority="1000" mode="M38">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="IncidentState"
                       id="IncidentState_self_rule"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2203_IncidentState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2203: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())">
               <xsl:attribute name="id">2204_IncidentState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2204: Field must be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../InjuryZip != '') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../InjuryZip != '') then(@biu='1') else(true())">
               <xsl:attribute name="id">2205_IncidentState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2205: Element must be Not Applicable when Incident Location Zip/Postal Code is documented
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M38"/>
   <xsl:template match="@*|node()" priority="-2" mode="M38">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>
   <!--PATTERN IncidentCountyIncidentCounty Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentCounty Assertions</svrl:text>
   <!--RULE IncidentCounty_self_rules-->
   <xsl:template match="IncidentCounty" priority="1000" mode="M39">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="IncidentCounty"
                       id="IncidentCounty_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2303_IncidentCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2303: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())">
               <xsl:attribute name="id">2304_IncidentCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2304: Field must be Not Applicable (Non-US hospitals)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../InjuryZip != '') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../InjuryZip != '') then(@biu='1') else(true())">
               <xsl:attribute name="id">2305_IncidentCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2305: Element must be Not Applicable when Incident Location Zip/Postal Code is documented
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M39"/>
   <xsl:template match="@*|node()" priority="-2" mode="M39">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>
   <!--PATTERN IncidentCityIncidentCity Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">IncidentCity Assertions</svrl:text>
   <!--RULE IncidentCity_self_rules-->
   <xsl:template match="IncidentCity" priority="1000" mode="M40">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="IncidentCity"
                       id="IncidentCity_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2403_IncidentCity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2403: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())">
               <xsl:attribute name="id">2404_IncidentState</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2404: Field must be Not Applicable (Non-US hospitals)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../InjuryZip != '') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../InjuryZip != '') then(@biu='1') else(true())">
               <xsl:attribute name="id">2405_IncidentCounty</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2405: Element must be Not Applicable when Incident Location Zip/Postal Code is documented
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M40"/>
   <xsl:template match="@*|node()" priority="-2" mode="M40">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>
   <!--PATTERN ProtectiveDeviceProtectiveDevice Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ProtectiveDevice Assertions</svrl:text>
   <!--RULE ProtectiveDevice_self_rules-->
   <xsl:template match="ProtectiveDevice" priority="1000" mode="M41">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="ProtectiveDevice"
                       id="ProtectiveDevice_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2502_ProtectiveDevice</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2502: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not (@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not (@biu='1')">
               <xsl:attribute name="id">2507_ProtectiveDevice</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2507: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='2') then(every $element in ./../../item/ProtectiveDevice satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='2') then(every $element in ./../../item/ProtectiveDevice satisfies $element='') else(true())">
               <xsl:attribute name="id">2508_ProtectiveDevice</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2508: Element cannot be Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M41"/>
   <xsl:template match="@*|node()" priority="-2" mode="M41">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>
   <!--PATTERN ChildSpecificRestraintChildSpecificRestraint Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ChildSpecificRestraint Assertions</svrl:text>
   <!--RULE ChildSpecificRestraint_self_rules-->
   <xsl:template match="ChildSpecificRestraint" priority="1000" mode="M42">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="ChildSpecificRestraint"
                       id="ChildSpecificRestraint_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2603_ChildSpecificRestraint</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2603: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1') or (every $element in (../ProtectiveDevices/item/ProtectiveDevice) satisfies $element != '6')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@biu='1') or (every $element in (../ProtectiveDevices/item/ProtectiveDevice) satisfies $element != '6')">
               <xsl:attribute name="id">2604_ChildSpecificRestraint</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2604: Field cannot be Not Applicable when Protective Device is 6 (Child Restraint)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M42"/>
   <xsl:template match="@*|node()" priority="-2" mode="M42">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>
   <!--PATTERN AirbagDeploymentAirbagDeployment Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AirbagDeployment Assertions</svrl:text>
   <!--RULE AirbagDeployment_self_rules-->
   <xsl:template match="AirbagDeployment" priority="1000" mode="M43">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AirbagDeployment"
                       id="AirbagDeployment_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2703_AirbagDeployment_not_blank</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2703: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='2') then(every $element in ./../../item/AirbagDeployment satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='2') then(every $element in ./../../item/AirbagDeployment satisfies $element='') else(true())">
               <xsl:attribute name="id">2704_AirbagDeployment_not_blank</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2704:  Field cannot be "Not Applicable" when Protective Device is "8. Airbag Present"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='2') then(every $element in ./../../item/AirbagDeployment satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='2') then(every $element in ./../../item/AirbagDeployment satisfies $element='') else(true())">
               <xsl:attribute name="id">2705_AirbagDeployment</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2705: Element cannot be Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <!--PATTERN AbuseReportAbuseReport Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AbuseReport Assertions</svrl:text>
   <!--RULE AbuseReport_self_rules-->
   <xsl:template match="AbuseReport" priority="1000" mode="M44">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AbuseReport"
                       id="AbuseReport_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">9202_AbuseReport</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9202: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9203_AbuseReport</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9203: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M44"/>
   <xsl:template match="@*|node()" priority="-2" mode="M44">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>
   <!--PATTERN AbuseInvestigationAbuseInvestigation Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AbuseInvestigation Assertions</svrl:text>
   <!--RULE AbuseInvestigation_self_rules-->
   <xsl:template match="AbuseInvestigation" priority="1000" mode="M45">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AbuseInvestigation"
                       id="AbuseInvestigation_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9302_AbuseInvestigation</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9302: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../AbuseReport ='2') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../AbuseReport ='2') then(@biu='1') else(true())">
               <xsl:attribute name="id">9304_AbuseInvestigation</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9304: Field must be Not Applicable when Report of Physical Abuse is No
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M45"/>
   <xsl:template match="@*|node()" priority="-2" mode="M45">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>
   <!--PATTERN CaregiverAtDischargeCaregiverAtDischarge Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">CaregiverAtDischarge Assertions</svrl:text>
   <!--RULE CaregiverAtDischarge_self_rules-->
   <xsl:template match="CaregiverAtDischarge" priority="1000" mode="M46">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="CaregiverAtDischarge"
                       id="CaregiverAtDischarge_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9402_CaregiverAtDischarge</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9402: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../AbuseReport ='2') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../AbuseReport ='2') then(@biu='1') else(true())">
               <xsl:attribute name="id">9404_AbuseInvestigation</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9404: Field must be Not Applicable when Report of Physical Abuse is No
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M46"/>
   <xsl:template match="@*|node()" priority="-2" mode="M46">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>
   <!--PATTERN EmsNotifyDateEmsNotifyDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsNotifyDate Assertions</svrl:text>
   <!--RULE EmsNotifyDate_self_rules-->
   <xsl:template match="EmsNotifyDate" priority="1000" mode="M47">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsNotifyDate"
                       id="EmsNotifyDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2809_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2809: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">2803_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2803: EMS Dispatch Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EmsArrivalDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EmsArrivalDate, .)">
               <xsl:attribute name="id">2804_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2804: EMS Dispatch Date is later than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EmsLeftDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EmsLeftDate, .)">
               <xsl:attribute name="id">2805_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2805: EMS Dispatch Date is later than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalArrivalDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalArrivalDate, .)">
               <xsl:attribute name="id">2806_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2806: EMS Dispatch Date is later than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">2807_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2807: EMS Dispatch Date is later than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">2808_EmsNotifyDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2808: EMS Dispatch Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M47"/>
   <xsl:template match="@*|node()" priority="-2" mode="M47">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>
   <!--PATTERN EmsNotifyTimeEmsNotifyTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsNotifyTime Assertions</svrl:text>
   <!--RULE EmsNotifyTime_self_rules-->
   <xsl:template match="EmsNotifyTime" priority="1000" mode="M48">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsNotifyTime"
                       id="EmsNotifyTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">2908_EmsNotifyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2908: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsNotifyDate, ../EmsArrivalDate) or fct:notLessThanTime(../EmsArrivalTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsNotifyDate, ../EmsArrivalDate) or fct:notLessThanTime(../EmsArrivalTime, .)">
               <xsl:attribute name="id">2903_EmsNotifyTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2903: EMS Dispatch Time is later than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsNotifyDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsNotifyDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)">
               <xsl:attribute name="id">2904_EmsNotifyTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2904: EMS Dispatch Time is later than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsNotifyDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsNotifyDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
               <xsl:attribute name="id">2905_EmsNotifyTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2905: EMS Dispatch Time is later than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsNotifyDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsNotifyDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">2906_EmsNotifyTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2906: EMS Dispatch Time is later than ED Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsNotifyDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsNotifyDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">2907_EmsNotifyTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			2907: EMS Dispatch Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M48"/>
   <xsl:template match="@*|node()" priority="-2" mode="M48">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>
   <!--PATTERN EmsArrivalDateEmsArrivalDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsArrivalDate Assertions</svrl:text>
   <!--RULE EmsArrivalDate_self_rules-->
   <xsl:template match="EmsArrivalDate" priority="1000" mode="M49">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsArrivalDate"
                       id="EmsArrivalDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3010_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3010: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">3003_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3003: EMS Unit Arrival on Scene Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsNotifyDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsNotifyDate)">
               <xsl:attribute name="id">3004_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3004: EMS Unit Arrival on Scene Date is earlier than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EmsLeftDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EmsLeftDate, .)">
               <xsl:attribute name="id">3005_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3005: EMS Unit Arrival on Scene Date is later than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalArrivalDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalArrivalDate, .)">
               <xsl:attribute name="id">3006_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3006: EMS Unit Arrival on Scene Date is later than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">3007_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3007: EMS Unit Arrival on Scene Date is later than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">3008_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3008: EMS Unit Arrival on Scene Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or ../EmsNotifyDate = '' or (fct:durationParse(../EmsNotifyDate, ., '2') &lt; 7)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or ../EmsNotifyDate = '' or (fct:durationParse(../EmsNotifyDate, ., '2') &lt; 7)">
               <xsl:attribute name="id">3009_EmsArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3009: EMS Unit Arrival on Scene Date minus EMS Dispatch Date is greater than 7 days
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M49"/>
   <xsl:template match="@*|node()" priority="-2" mode="M49">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>
   <!--PATTERN EmsArrivalTimeEmsArrivalTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsArrivalTime Assertions</svrl:text>
   <!--RULE EmsArrivalTime_self_rules-->
   <xsl:template match="EmsArrivalTime" priority="1000" mode="M50">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsArrivalTime"
                       id="EmsArrivalTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3108_EmsArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3108: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsArrivalDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsArrivalDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
               <xsl:attribute name="id">3103_EmsArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3103: EMS Unit Arrival on Scene Time is earlier than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsArrivalDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsArrivalDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)">
               <xsl:attribute name="id">3104_EmsArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3104: EMS Unit Arrival on Scene Time is later than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsArrivalDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsArrivalDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
               <xsl:attribute name="id">3105_EmsArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3105: EMS Unit Arrival on Scene Time is later than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsArrivalDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsArrivalDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">3106_EmsArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3106: EMS Unit Arrival on Scene Time is later than ED Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsArrivalDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsArrivalDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">3107_EmsArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3107: EMS Unit Arrival on Scene Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M50"/>
   <xsl:template match="@*|node()" priority="-2" mode="M50">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>
   <!--PATTERN EmsLeftDateEmsLeftDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsLeftDate Assertions</svrl:text>
   <!--RULE EmsLeftDate_self_rules-->
   <xsl:template match="EmsLeftDate" priority="1000" mode="M51">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsLeftDate"
                       id="EmsLeftDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3210_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3210: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">3203_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3203: EMS Unit Scene Departure Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsNotifyDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsNotifyDate)">
               <xsl:attribute name="id">3204_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3204: EMS Unit Scene Departure Date is earlier than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsArrivalDate)">
               <xsl:attribute name="id">3205_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3205: EMS Unit Scene Departure Date is earlier than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalArrivalDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalArrivalDate, .)">
               <xsl:attribute name="id">3206_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3206: EMS Unit Scene Departure Date is later than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">3207_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3207: EMS Unit Scene Departure Date is later than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">3208_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3208: EMS Unit Scene Departure Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or ../EmsArrivalDate = '' or  (fct:durationParse(., ../EmsArrivalDate, '2') &lt; 7)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or ../EmsArrivalDate = '' or (fct:durationParse(., ../EmsArrivalDate, '2') &lt; 7)">
               <xsl:attribute name="id">3209_EmsLeftDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3209: EMS Unit Scene Departure Date minus EMS Unit Arrival on Scene Date is greater than 7 days
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M51"/>
   <xsl:template match="@*|node()" priority="-2" mode="M51">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>
   <!--PATTERN EmsLeftTimeEmsLeftTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsLeftTime Assertions</svrl:text>
   <!--RULE EmsLeftTime_self_rules-->
   <xsl:template match="EmsLeftTime" priority="1000" mode="M52">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsLeftTime"
                       id="EmsLeftTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3308_EmsLeftTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3308: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsLeftDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsLeftDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
               <xsl:attribute name="id">3303_EmsLeftTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3303: EMS Unit Scene Departure Time is earlier than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsLeftDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsLeftDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
               <xsl:attribute name="id">3304_EmsLeftTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3304: EMS Unit Scene Departure Time is earlier than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsLeftDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsLeftDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
               <xsl:attribute name="id">3305_EmsLeftTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3305: EMS Unit Scene Departure Time is later than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsLeftDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsLeftDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">3306_EmsLeftTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3306: EMS Unit Scene Departure Time is later than the ED Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EmsLeftDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EmsLeftDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">3307_EmsLeftTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3307: EMS Unit Scene Departure Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M52"/>
   <xsl:template match="@*|node()" priority="-2" mode="M52">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>
   <!--PATTERN TransportModeTransportMode Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TransportMode Assertions</svrl:text>
   <!--RULE TransportMode_self_rules-->
   <xsl:template match="TransportMode" priority="1000" mode="M53">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TransportMode"
                       id="TransportMode_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3402_TransportMode</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3402: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">3404_TransportMode</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3404: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M53"/>
   <xsl:template match="@*|node()" priority="-2" mode="M53">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>
   <!--PATTERN OtherTransportModeOtherTransportMode Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">OtherTransportMode Assertions</svrl:text>
   <!--RULE OtherTransportMode_self_rules-->
   <xsl:template match="OtherTransportMode" priority="1000" mode="M54">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="OtherTransportMode"
                       id="OtherTransportMode_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3502_OtherTransportMode</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3502: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M54"/>
   <xsl:template match="@*|node()" priority="-2" mode="M54">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>
   <!--PATTERN EmsSbpEmsSbp Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsSbp Assertions</svrl:text>
   <!--RULE EmsSbp_self_rules-->
   <xsl:template match="EmsSbp" priority="1000" mode="M55">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsSbp"
                       id="EmsSbp_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3602_EmsSbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 220) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
               <xsl:attribute name="id">3603_EmsSbp</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3603: The value is above 220
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 30) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
               <xsl:attribute name="id">3607_EmsSbp</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3607: SBP value is below 30
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M55"/>
   <xsl:template match="@*|node()" priority="-2" mode="M55">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>
   <!--PATTERN EmsPulseRateEmsSbp Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsSbp Assertions</svrl:text>
   <!--RULE EmsPulseRate_self_rules-->
   <xsl:template match="EmsPulseRate" priority="1000" mode="M56">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsPulseRate"
                       id="EmsPulseRate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3702_EmsPulseRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 220) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
               <xsl:attribute name="id">3703_EmsPulseRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3703: The value submitted is above 220
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 30) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
               <xsl:attribute name="id">3707_EmsPulseRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3707: Pulse rate submitted is below 30
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M56"/>
   <xsl:template match="@*|node()" priority="-2" mode="M56">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>
   <!--PATTERN EmsRespiratoryRateEMS RespiratoryRate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EMS RespiratoryRate Assertions</svrl:text>
   <!--RULE EmsRespiratoryRate_self_rules-->
   <xsl:template match="EmsRespiratoryRate" priority="1000" mode="M57">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsRespiratoryRate"
                       id="EmsRespiratoryRate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3802_EmsRespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 5) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 5) else (true())">
               <xsl:attribute name="id">3807_EmsRespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3807: The value submitted is below 5
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 75) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 75) else (true())">
               <xsl:attribute name="id">3807_EmsRespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3808: The value is above 75
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M57"/>
   <xsl:template match="@*|node()" priority="-2" mode="M57">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>
   <!--PATTERN EmsPulseOximetryEmsPulseOximetry Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsPulseOximetry Assertions</svrl:text>
   <!--RULE EmsPulseOximetry_self_rules-->
   <xsl:template match="EmsPulseOximetry" priority="1000" mode="M58">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsPulseOximetry"
                       id="EmsPulseOximetry_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">3902_EmsPulseOximetry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3902: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 40) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 40) else (true())">
               <xsl:attribute name="id">3907_EmsRespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			3907: The value submitted is below 40
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M58"/>
   <xsl:template match="@*|node()" priority="-2" mode="M58">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>
   <!--PATTERN EmsGcsEyeEmsGcsEye Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsGcsEye Assertions</svrl:text>
   <!--RULE EmsGcsEye_self_rules-->
   <xsl:template match="EmsGcsEye" priority="1000" mode="M59">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsGcsEye"
                       id="EmsGcsEye_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4003_EmsGcsEye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4003: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcs40Eye !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcs40Eye !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">4006_EmsGcsEye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4006: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Eye is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M59"/>
   <xsl:template match="@*|node()" priority="-2" mode="M59">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>
   <!--PATTERN EmsGcsVerbalEmsGcsVerbal Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsGcsVerbal Assertions</svrl:text>
   <!--RULE EmsGcsVerbal_self_rules-->
   <xsl:template match="EmsGcsVerbal" priority="1000" mode="M60">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsGcsVerbal"
                       id="EmsGcsVerbal_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4103_EmsGcsVerbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4103: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcs40Verbal !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcs40Verbal !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">4106_EmsGcsVerbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4106: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Verbal is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M60"/>
   <xsl:template match="@*|node()" priority="-2" mode="M60">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>
   <!--PATTERN EmsGcsMotorEmsGcsMotor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsGcsMotor Assertions</svrl:text>
   <!--RULE EmsGcsMotor_self_rules-->
   <xsl:template match="EmsGcsMotor" priority="1000" mode="M61">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsGcsMotor"
                       id="EmsGcsMotor_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4203_EmsGcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4203: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcs40Motor !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcs40Motor !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">4206_EmsGcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4206: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Motor is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M61"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M61"/>
   <xsl:template match="@*|node()" priority="-2" mode="M61">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M61"/>
   </xsl:template>
   <!--PATTERN EmsTotalGcsEmsTotalGcs Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsTotalGcs Assertions</svrl:text>
   <!--RULE EmsTotalGcs_self_rules-->
   <xsl:template match="EmsTotalGcs" priority="1000" mode="M62">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsTotalGcs"
                       id="EmsTotalGcs_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4304_EmsTotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4304: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(../EmsGcsEye castable as xs:integer and ../EmsGcsVerbal castable as xs:integer and ../EmsGcsMotor castable as xs:integer and . castable as xs:integer)    then (xs:integer(.) = xs:integer(../EmsGcsEye) + xs:integer(../EmsGcsVerbal) + xs:integer(../EmsGcsMotor)) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../EmsGcsEye castable as xs:integer and ../EmsGcsVerbal castable as xs:integer and ../EmsGcsMotor castable as xs:integer and . castable as xs:integer) then (xs:integer(.) = xs:integer(../EmsGcsEye) + xs:integer(../EmsGcsVerbal) + xs:integer(../EmsGcsMotor)) else (true())">
               <xsl:attribute name="id">4303_TotalGcs</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4303: Initial Field GCS - Total does not equal the sum of Initial Field GCS - Eye, Initial Field GCS - Verbal, and Initial Field GCS - Motor
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcs40Eye !='' or ./../EmsGcs40Verbal !='' or ./../EmsGcs40Motor !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcs40Eye !='' or ./../EmsGcs40Verbal !='' or ./../EmsGcs40Motor !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">4306_TotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4306: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Eye, Initial Field GCS 40 – Verbal, or Initial Field GCS 40 – Motor are reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M62"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M62"/>
   <xsl:template match="@*|node()" priority="-2" mode="M62">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M62"/>
   </xsl:template>
   <!--PATTERN EmsGcs40EyeEmsGcs40Eye Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsGcs40Eye Assertions</svrl:text>
   <!--RULE EmsGcs40Eye_self_rules-->
   <xsl:template match="EmsGcs40Eye" priority="1000" mode="M63">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsGcs40Eye"
                       id="EmsGcs40Eye_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">15003_EmsGcs40Eye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15003: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcsEye !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcsEye !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">15006_EmsGcs40Eye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15006: Element must be Not Known/Not Recorded when Initial Field GCS – Eye is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M63"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M63"/>
   <xsl:template match="@*|node()" priority="-2" mode="M63">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M63"/>
   </xsl:template>
   <!--PATTERN EmsGcs40VerbalEmsGcs40Motor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsGcs40Motor Assertions</svrl:text>
   <!--RULE EmsGcs40Verbal_self_rules-->
   <xsl:template match="EmsGcs40Verbal" priority="1000" mode="M64">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsGcs40Verbal"
                       id="EmsGcs40Verbal_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">15103_EmsGcs40Verbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15103: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcsVerbal !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcsVerbal !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">15106_EmsGcs40Verbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15106: Element must be Not Known/Not Recorded when Initial Field GCS – Verbal is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M64"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M64"/>
   <xsl:template match="@*|node()" priority="-2" mode="M64">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M64"/>
   </xsl:template>
   <!--PATTERN EmsGcs40MotorEmsGcs40Motor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmsGcs40Motor Assertions</svrl:text>
   <!--RULE EmsGcs40Motor_self_rules-->
   <xsl:template match="EmsGcs40Motor" priority="1000" mode="M65">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmsGcs40Motor"
                       id="EmsGcs40Motor_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">15203_EmsGcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15203: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../EmsGcsMotor !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../EmsGcsMotor !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">15206_EmsGcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15206: Element must be Not Known/Not Recorded when Initial Field GCS – Motor is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M65"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M65"/>
   <xsl:template match="@*|node()" priority="-2" mode="M65">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M65"/>
   </xsl:template>
   <!--PATTERN InterFacilityTransferInterFacilityTransfer Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">InterFacilityTransfer Assertions</svrl:text>
   <!--RULE InterFacilityTransfer_self_rules-->
   <xsl:template match="InterFacilityTransfer" priority="1000" mode="M66">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="InterFacilityTransfer"
                       id="InterFacilityTransfer_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4401_InterFacilityTransfer</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4401: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">4405_InterFacilityTransfer</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4405: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M66"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M66"/>
   <xsl:template match="@*|node()" priority="-2" mode="M66">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M66"/>
   </xsl:template>
   <!--PATTERN TraumaCenterCriterionTraumaCenterCriterion Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TraumaCenterCriterion Assertions</svrl:text>
   <!--RULE TraumaCenterCriterion_self_rules-->
   <xsl:template match="TraumaCenterCriterion" priority="1000" mode="M67">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TraumaCenterCriterion"
                       id="TraumaCenterCriterion_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9502_TraumaCenterCriterion</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9502: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1', '2')) then(every $element in ./../../item/TraumaCenterCriterion satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1', '2')) then(every $element in ./../../item/TraumaCenterCriterion satisfies $element='') else(true())">
               <xsl:attribute name="id">9506_TraumaCenterCriterion</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9506: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M67"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M67"/>
   <xsl:template match="@*|node()" priority="-2" mode="M67">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M67"/>
   </xsl:template>
   <!--PATTERN VehicularPedestrianOtherVehicularPedestrianOther Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">VehicularPedestrianOther Assertions</svrl:text>
   <!--RULE VehicularPedestrianOther_self_rules-->
   <xsl:template match="VehicularPedestrianOther" priority="1000" mode="M68">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="VehicularPedestrianOther"
                       id="VehicularPedestrianOther_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9602_VehicularPedestrianOther</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1', '2')) then(every $element in ./../../item/VehicularPedestrianOther satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1', '2')) then(every $element in ./../../item/VehicularPedestrianOther satisfies $element='') else(true())">
               <xsl:attribute name="id">9607_VehicularPedestrianOther</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9607: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M68"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M68"/>
   <xsl:template match="@*|node()" priority="-2" mode="M68">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M68"/>
   </xsl:template>
   <!--PATTERN PrehospitalCardiacArrestPrehospitalCardiacArrest Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PrehospitalCardiacArrest Assertions</svrl:text>
   <!--RULE PrehospitalCardiacArrest_self_rules-->
   <xsl:template match="PrehospitalCardiacArrest" priority="1000" mode="M69">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PrehospitalCardiacArrest"
                       id="PrehospitalCardiacArrest_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu = ('1', '2')">
               <xsl:attribute name="id">9702_PrehospitalCardiacArrest</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">9703_PrehospitalCardiacArrest</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9703: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M69"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M69"/>
   <xsl:template match="@*|node()" priority="-2" mode="M69">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M69"/>
   </xsl:template>
   <!--PATTERN HospitalArrivalDateHospitalArrivalDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalArrivalDate Assertions</svrl:text>
   <!--RULE HospitalArrivalDate_self_rules-->
   <xsl:template match="HospitalArrivalDate" priority="1000" mode="M70">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalArrivalDate"
                       id="HospitalArrivalDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4503_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4503: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('2'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('2'))">
               <xsl:attribute name="id">4505_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4505: Field cannot be Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsNotifyDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsNotifyDate)">
               <xsl:attribute name="id">4506_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4506: ED/Hospital Arrival Date is earlier than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsArrivalDate)">
               <xsl:attribute name="id">4507_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4507: ED/Hospital Arrival Date is earlier than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsLeftDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsLeftDate)">
               <xsl:attribute name="id">4508_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4508: ED/Hospital Arrival Date is earlier than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">4509_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4509: ED/Hospital Arrival Date is later than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">4510_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4510: ED/Hospital Arrival Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">4511_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4511: ED/Hospital Arrival Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or not (.) or ../IncidentDate = '' or not (../IncidentDate) or not (fct:durationParse(../IncidentDate, ., '2') &gt;= 30)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or not (.) or ../IncidentDate = '' or not (../IncidentDate) or not (fct:durationParse(../IncidentDate, ., '2') &gt;= 30)">
               <xsl:attribute name="id">4513_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4513: ED/Hospital Arrival Date minus Injury Incident Date should be less than 30 days
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">4515_HospitalArrivalDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4515: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M70"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M70"/>
   <xsl:template match="@*|node()" priority="-2" mode="M70">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M70"/>
   </xsl:template>
   <!--PATTERN HospitalArrivalTimeHospitalArrivalTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalArrivalTime Assertions</svrl:text>
   <!--RULE HospitalArrivalTime_self_rules-->
   <xsl:template match="HospitalArrivalTime" priority="1000" mode="M71">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalArrivalTime"
                       id="HospitalArrivalTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4603_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4603: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalArrivalDate, ../EmsNotifyDate) or  fct:notLessThanTime(., ../EmsNotifyTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalArrivalDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
               <xsl:attribute name="id">4604_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4604: ED/Hospital Arrival Time is earlier than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalArrivalDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalArrivalDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
               <xsl:attribute name="id">4605_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4605: ED/Hospital Arrival Time is earlier than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalArrivalDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalArrivalDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)">
               <xsl:attribute name="id">4606_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4606: ED/Hospital Arrival Time is earlier than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalArrivalDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalArrivalDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">4607_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4607: ED/Hospital Arrival Time is later than ED Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">4608_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4608: ED/Hospital Arrival Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">4609_HospitalArrivalTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4609: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M71"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M71"/>
   <xsl:template match="@*|node()" priority="-2" mode="M71">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M71"/>
   </xsl:template>
   <!--PATTERN SbpSbp Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Sbp Assertions</svrl:text>
   <!--RULE Sbp_self_rules-->
   <xsl:template match="Sbp" priority="1000" mode="M72">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Sbp"
                       id="Sbp_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4702_Sbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 220) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
               <xsl:attribute name="id">4704_Sbp</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4704: The value is above 220
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">4705_Sbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4705: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 30) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
               <xsl:attribute name="id">4707_Sbp</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4707: SBP value is below 30
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M72"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M72"/>
   <xsl:template match="@*|node()" priority="-2" mode="M72">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M72"/>
   </xsl:template>
   <!--PATTERN PulseRatePulseRate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PulseRate Assertions</svrl:text>
   <!--RULE PulseRate_self_rules-->
   <xsl:template match="PulseRate" priority="1000" mode="M73">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PulseRate"
                       id="PulseRate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4802_PulseRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 220) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
               <xsl:attribute name="id">4804_PulseRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4804: The value is above 220
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">4805_PulseRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4805: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 30) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
               <xsl:attribute name="id">4804_PulseRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4807: The value is below 30
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M73"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M73"/>
   <xsl:template match="@*|node()" priority="-2" mode="M73">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M73"/>
   </xsl:template>
   <!--PATTERN TemperatureTemperature Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Temperature Assertions</svrl:text>
   <!--RULE Temperature_self_rules-->
   <xsl:template match="Temperature" priority="1000" mode="M74">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Temperature"
                       id="Temperature_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">4902_Temperature</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4902: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &lt; 42.0) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &lt; 42.0) else (true())">
               <xsl:attribute name="id">4903_Temperature</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4903: The value is above 42.0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">4904_Temperature</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4904: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &gt; 20.0) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &gt; 20.0) else (true())">
               <xsl:attribute name="id">4906_Temperature</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			4906: Temperature below 20.0 Celsius
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M74"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M74"/>
   <xsl:template match="@*|node()" priority="-2" mode="M74">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M74"/>
   </xsl:template>
   <!--PATTERN RespiratoryRateRespiratoryRate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">RespiratoryRate Assertions</svrl:text>
   <!--RULE RespiratoryRate_self_rules-->
   <xsl:template match="RespiratoryRate" priority="1000" mode="M75">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="RespiratoryRate"
                       id="RespiratoryRate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5002_RespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5002:Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../Age"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(../Age castable as xs:integer and ../AgeUnits castable as xs:integer and . castable as xs:integer) then ((../Age &gt;= 6 and ../AgeUnits=4 and . &lt;= 99) or ((../Age &lt; 6 or ../AgeUnits!=4) and . &lt;= 120)) else (if(. castable as xs:integer) then(. &lt; 120) else(true()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../Age castable as xs:integer and ../AgeUnits castable as xs:integer and . castable as xs:integer) then ((../Age &gt;= 6 and ../AgeUnits=4 and . &lt;= 99) or ((../Age &lt; 6 or ../AgeUnits!=4) and . &lt;= 120)) else (if(. castable as xs:integer) then(. &lt; 120) else(true()))">
               <xsl:attribute name="id">5001_RespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5001: Invalid value. RR cannot be &gt; 99 for age in years &gt;= 6 OR RR cannot be &gt; 120 for age in years &lt; 6. If age and age units are not valued, RR cannot be &gt; 120.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(../Age castable as xs:integer and ../AgeUnits castable as xs:integer and . castable as xs:integer) then ((../Age &gt;= 6 and ../AgeUnits='4') or ((../Age &lt; 6 or ../AgeUnits != '4') and (. &lt;= 99))) else (if(. castable as xs:integer) then(. &lt; 99) else(true()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../Age castable as xs:integer and ../AgeUnits castable as xs:integer and . castable as xs:integer) then ((../Age &gt;= 6 and ../AgeUnits='4') or ((../Age &lt; 6 or ../AgeUnits != '4') and (. &lt;= 99))) else (if(. castable as xs:integer) then(. &lt; 99) else(true()))">
               <xsl:attribute name="id">5005_RespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5005: Invalid, out of range. RR cannot be &gt; 99 and &lt;=120 for age in years &lt; 6. If age and age units are not valued, RR cannot be &gt; 99.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5006_RespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5006: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 5) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 5) else (true())">
               <xsl:attribute name="id">5007_RespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5007: The value is below 5
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 75) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 75) else (true())">
               <xsl:attribute name="id">5008_RespiratoryRate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5008: The value is above 75
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M75"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M75"/>
   <xsl:template match="@*|node()" priority="-2" mode="M75">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M75"/>
   </xsl:template>
   <!--PATTERN RespiratoryAssistanceRespiratoryAssistance Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">RespiratoryAssistance Assertions</svrl:text>
   <!--RULE RespiratoryAssistance_self_rules-->
   <xsl:template match="RespiratoryAssistance" priority="1000" mode="M76">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="RespiratoryAssistance"
                       id="RespiratoryAssistance_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5102_RespiratoryAssistance</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5102:Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../RespiratoryRate/@biu ='2') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../RespiratoryRate/@biu ='2') then(@biu='1') else(true())">
               <xsl:attribute name="id">5103_RespiratoryAssistance</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5103:Element must be Not Applicable when Initial ED/Hospital Respiratory Rate is Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M76"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M76"/>
   <xsl:template match="@*|node()" priority="-2" mode="M76">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M76"/>
   </xsl:template>
   <!--PATTERN PulseOximetryPulseOximetry Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PulseOximetry Assertions</svrl:text>
   <!--RULE PulseOximetry_self_rules-->
   <xsl:template match="PulseOximetry" priority="1000" mode="M77">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PulseOximetry"
                       id="PulseOximetry_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5202_PulseOximetry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5202: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5205_PulseOximetry</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5205: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt; 40) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt; 40) else (true())">
               <xsl:attribute name="id">5207_PulseOximetry</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5207: The value is below 40
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M77"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M77"/>
   <xsl:template match="@*|node()" priority="-2" mode="M77">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M77"/>
   </xsl:template>
   <!--PATTERN SupplementalOxygenSupplementalOxygen Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SupplementalOxygen Assertions</svrl:text>
   <!--RULE SupplementalOxygen_self_rules-->
   <xsl:template match="SupplementalOxygen" priority="1000" mode="M78">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="SupplementalOxygen"
                       id="SupplementalOxygen_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5303_SupplementalOxygen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5303: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../PulseOximetry/@biu ='2') then(@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../PulseOximetry/@biu ='2') then(@biu='1') else(true())">
               <xsl:attribute name="id">5304_SupplementalOxygen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5304: Element must be Not Applicable when Initial ED/Hospital Oxygen Saturation is Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M78"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M78"/>
   <xsl:template match="@*|node()" priority="-2" mode="M78">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M78"/>
   </xsl:template>
   <!--PATTERN GcsEyeGcsEye Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">GcsEye Assertions</svrl:text>
   <!--RULE GcsEye_self_rules-->
   <xsl:template match="GcsEye" priority="1000" mode="M79">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="GcsEye"
                       id="GcsEye_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5403_GcsEye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5403: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5404_GcsEye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5404: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Gcs40Eye != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Gcs40Eye != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">5405_GcsEye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5405: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Eye is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M79"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M79"/>
   <xsl:template match="@*|node()" priority="-2" mode="M79">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M79"/>
   </xsl:template>
   <!--PATTERN GcsVerbalGcsVerbal Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">GcsVerbal Assertions</svrl:text>
   <!--RULE GcsVerbal_self_rules-->
   <xsl:template match="GcsVerbal" priority="1000" mode="M80">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="GcsVerbal"
                       id="GcsVerbal_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5503_GcsVerbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5503: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5504_GcsVerbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5504: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Gcs40Verbal != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Gcs40Verbal != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">5505_GcsVerbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5505: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Verbal is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M80"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M80"/>
   <xsl:template match="@*|node()" priority="-2" mode="M80">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M80"/>
   </xsl:template>
   <!--PATTERN GcsMotorGcsMotor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">GcsMotor Assertions</svrl:text>
   <!--RULE GcsMotor_self_rules-->
   <xsl:template match="GcsMotor" priority="1000" mode="M81">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="GcsMotor"
                       id="GcsMotor_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5603_GcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5603: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5604_GcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5604: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Gcs40Motor != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Gcs40Motor != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">5605_GcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5605: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 - Motor is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M81"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M81"/>
   <xsl:template match="@*|node()" priority="-2" mode="M81">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M81"/>
   </xsl:template>
   <!--PATTERN TotalGcsTotalGcs Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TotalGcs Assertions</svrl:text>
   <!--RULE TotalGcs_self_rules-->
   <xsl:template match="TotalGcs" priority="1000" mode="M82">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TotalGcs"
                       id="TotalGcs_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5705_TotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5705: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5706_TotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5706: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="not (../GcsEye !='' and ../GcsVerbal != '' and ../GcsMotor != '') or (. = ../GcsEye + ../GcsVerbal + ../GcsMotor)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not (../GcsEye !='' and ../GcsVerbal != '' and ../GcsMotor != '') or (. = ../GcsEye + ../GcsVerbal + ../GcsMotor)">
               <xsl:attribute name="id">5703_TotalGcs</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5703: Initial ED/Hospital GCS - Total does not equal the sum of Initial ED/Hospital GCS - Eye, Initial ED/Hospital GCS - Verbal, and Initial ED/Hospital GCS - Motor
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(../Gcs40Eye != '' or ../Gcs40Verbal != '' or ../Gcs40Motor != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../Gcs40Eye != '' or ../Gcs40Verbal != '' or ../Gcs40Motor != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">5707_TotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5707: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Eye, Initial ED/Hospital GCS 40 – Verbal, or Initial ED/Hospital GCS 40 – Motor are reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M82"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M82"/>
   <xsl:template match="@*|node()" priority="-2" mode="M82">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M82"/>
   </xsl:template>
   <!--PATTERN GcsQualifierGcsQualifier Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">GcsQualifier Assertions</svrl:text>
   <!--RULE GcsQualifier_self_rules-->
   <xsl:template match="GcsQualifier" priority="1000" mode="M83">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="GcsQualifier"
                       id="GcsQualifier_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5802_GcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5803_GcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5803: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../../../Gcs40Eye != '' or ./../../../Gcs40Verbal != '' or ./../../../Gcs40Motor != '') then(every $element in ./../../item/GcsQualifier satisfies $element/@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../../../Gcs40Eye != '' or ./../../../Gcs40Verbal != '' or ./../../../Gcs40Motor != '') then(every $element in ./../../item/GcsQualifier satisfies $element/@biu='2') else(true())">
               <xsl:attribute name="id">5804_GcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5804: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Eye, Initial ED/Hospital GCS 40 – Verbal, or Initial ED/Hospital GCS 40 – Motor are reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='2') then(every $element in ./../../item/GcsQualifier satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='2') then(every $element in ./../../item/GcsQualifier satisfies $element='') else(true())">
               <xsl:attribute name="id">5805_GcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5805: Element cannot be Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M83"/>
   <xsl:template match="@*|node()" priority="-2" mode="M83">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>
   <!--PATTERN Gcs40EyeGcs40Eye Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Gcs40Eye Assertions</svrl:text>
   <!--RULE Gcs40Eye_self_rules-->
   <xsl:template match="Gcs40Eye" priority="1000" mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Gcs40Eye"
                       id="Gcs40Eye_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">15303_Gcs40Eye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15303: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">15304_Gcs40Eye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15304: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../GcsEye !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../GcsEye !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">15306_Gcs40Eye</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15306: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS – Eye is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M84"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M84"/>
   <xsl:template match="@*|node()" priority="-2" mode="M84">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M84"/>
   </xsl:template>
   <!--PATTERN Gcs40VerbalGcs40Motor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Gcs40Motor Assertions</svrl:text>
   <!--RULE Gcs40Verbal_self_rules-->
   <xsl:template match="Gcs40Verbal" priority="1000" mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Gcs40Verbal"
                       id="Gcs40Verbal_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">15403_Gcs40Verbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15403: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">15404_Gcs40Verbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15404: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../GcsVerbal !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../GcsVerbal !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">15406_Gcs40Verbal</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15406: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS – Verbal is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M85"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M85"/>
   <xsl:template match="@*|node()" priority="-2" mode="M85">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M85"/>
   </xsl:template>
   <!--PATTERN Gcs40MotorGcs40Motor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Gcs40Motor Assertions</svrl:text>
   <!--RULE Gcs40Motor_self_rules-->
   <xsl:template match="Gcs40Motor" priority="1000" mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Gcs40Motor"
                       id="Gcs40Motor_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">15503_Gcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15503: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">15504_Gcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15504: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../GcsMotor !='') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../GcsMotor !='') then(@biu='2') else(true())">
               <xsl:attribute name="id">15506_Gcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			15506: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS – Motor is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M86"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M86"/>
   <xsl:template match="@*|node()" priority="-2" mode="M86">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M86"/>
   </xsl:template>
   <!--PATTERN HeightHeight Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Height Assertions</svrl:text>
   <!--RULE Height_self_rules-->
   <xsl:template match="Height" priority="1000" mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Height"
                       id="Height_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8502_Height</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8502: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">8504_Height</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8504: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &lt; 215) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &lt; 215) else (true())">
               <xsl:attribute name="id">8503_Height</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8503: The value is above 215
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &gt; 50) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &gt; 50) else (true())">
               <xsl:attribute name="id">8506_Height</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8506: The value is below 50
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M87"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M87"/>
   <xsl:template match="@*|node()" priority="-2" mode="M87">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M87"/>
   </xsl:template>
   <!--PATTERN WeightWeight Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Weight Assertions</svrl:text>
   <!--RULE Weight_self_rules-->
   <xsl:template match="Weight" priority="1000" mode="M88">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Weight"
                       id="Weight_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8602_Weight</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">8604_Weight</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8604: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &lt; 200) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &lt; 200) else (true())">
               <xsl:attribute name="id">8603_Weight</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8603: The value is above 200
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &gt; 3) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &gt; 3) else (true())">
               <xsl:attribute name="id">8606_Weight</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8606: The value is below 3
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M88"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M88"/>
   <xsl:template match="@*|node()" priority="-2" mode="M88">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M88"/>
   </xsl:template>
   <!--PATTERN DrugScreenDrugScreen Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">DrugScreen Assertions</svrl:text>
   <!--RULE DrugScreen_self_rules-->
   <xsl:template match="DrugScreen" priority="1000" mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="DrugScreen"
                       id="DrugScreen_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6012_DrugScreen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6012: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">6013_DrugScreen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6013: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='2') then(every $element in ./../../item/DrugScreen satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='2') then(every $element in ./../../item/DrugScreen satisfies $element='') else(true())">
               <xsl:attribute name="id">6014_DrugScreen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6014: Element cannot be Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M89"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M89"/>
   <xsl:template match="@*|node()" priority="-2" mode="M89">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M89"/>
   </xsl:template>
   <!--PATTERN AlcoholScreenAlcoholScreen Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AlcoholScreen Assertions</svrl:text>
   <!--RULE AlcoholScreen-->
   <xsl:template match="AlcoholScreen" priority="1000" mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AlcoholScreen"
                       id="AlcoholScreen"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5912_AlcoholScreen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5912: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">5913_AlcoholScreen</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5913: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M90"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M90"/>
   <xsl:template match="@*|node()" priority="-2" mode="M90">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M90"/>
   </xsl:template>
   <!--PATTERN AlcoholScreenResultAlcoholScreenResult Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AlcoholScreenResult Assertions</svrl:text>
   <!--RULE AlcoholScreenResult-->
   <xsl:template match="AlcoholScreenResult" priority="1000" mode="M91">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AlcoholScreenResult"
                       id="AlcoholScreenResult"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">5932_AlcoholScreenResult</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5932: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="../AlcoholScreen !='1' or not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="../AlcoholScreen !='1' or not(@biu='1')">
               <xsl:attribute name="id">5933_AlcoholScreenResult</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5933: Field cannot be Not Applicable when Alcohol Screen is 1 (Yes)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:decimal) then(. &lt; 0.4) else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:decimal) then(. &lt; 0.4) else (true())">
               <xsl:attribute name="id">5936_AlcoholScreenResult</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			5936: The value is above 0.4
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M91"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M91"/>
   <xsl:template match="@*|node()" priority="-2" mode="M91">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M91"/>
   </xsl:template>
   <!--PATTERN EdDischargeDispositionEdDischargeDisposition Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EdDischargeDisposition Assertions</svrl:text>
   <!--RULE EdDischargeDisposition_self_rules-->
   <xsl:template match="EdDischargeDisposition" priority="1000" mode="M92">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EdDischargeDisposition"
                       id="EdDischargeDisposition_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6102_EdDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('2'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('2'))">
               <xsl:attribute name="id">6104_EdDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6104: Field cannot be Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../HospitalDischargeOrdersWrittenDate"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="@biu=('1') or not(../HospitalDischargeOrdersWrittenDate[@biu]='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@biu=('1') or not(../HospitalDischargeOrdersWrittenDate[@biu]='1')">
               <xsl:attribute name="id">6106_EdDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6106: Field cannot not be Not Applicable when Hospital Discharge Date is Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../HospitalDischargeOrdersWrittenDate"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="@biu=('1') or not(../HospitalDischargeOrdersWrittenDate[@biu]='2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@biu=('1') or not(../HospitalDischargeOrdersWrittenDate[@biu]='2')">
               <xsl:attribute name="id">6107_EdDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6107: Field cannot not be Not Applicable when Hospital Discharge Date is Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../HospitalDischargeDisposition"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="@biu=('1') or not(../HospitalDischargeDisposition[@biu]='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@biu=('1') or not(../HospitalDischargeDisposition[@biu]='1')">
               <xsl:attribute name="id">6108_EdDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6108: Field cannot not be Not Applicable when Hospital Discharge Disposition is Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../HospitalDischargeDisposition"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="@biu=('1') or not(../HospitalDischargeDisposition[@biu]='2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@biu=('1') or not(../HospitalDischargeDisposition[@biu]='2')">
               <xsl:attribute name="id">6109_EdDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6109: Field cannot not be Not Applicable when Hospital Discharge Disposition is Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M92"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M92"/>
   <xsl:template match="@*|node()" priority="-2" mode="M92">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M92"/>
   </xsl:template>
   <!--PATTERN DeathInEdDeathInEd Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">DeathInEd Assertions</svrl:text>
   <!--RULE DeathInEd_self_rules-->
   <xsl:template match="DeathInEd" priority="1000" mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="DeathInEd"
                       id="DeathInEd_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6202_DeathInEd</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6202: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">6207_DeathInEd</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6207: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../Sbp,../PulseRate,../GcsMotor"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(../Sbp castable as xs:integer and ../PulseRate castable as xs:integer and ../GcsMotor castable as xs:integer) then(not(../Sbp &gt; 0 or ../PulseRate &gt; 0 or ../GcsMotor &gt; 1) or not(. ='1')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../Sbp castable as xs:integer and ../PulseRate castable as xs:integer and ../GcsMotor castable as xs:integer) then(not(../Sbp &gt; 0 or ../PulseRate &gt; 0 or ../GcsMotor &gt; 1) or not(. ='1')) else(true())">
               <xsl:attribute name="id">6208_DeathInEd</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6208: Field is 1 (Arrived with NO signs of life) when Initial ED/Hospital SBP &gt; 0, Pulse &gt; 0, OR GCS Motor &gt; 1. Please verify.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../Sbp,../PulseRate,../GcsMotor"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(../Sbp castable as xs:integer and ../PulseRate castable as xs:integer and ../GcsMotor castable as xs:integer) then(not(../Sbp = 0 and ../PulseRate = 0 and ../GcsMotor = 1)  or not(. ='2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../Sbp castable as xs:integer and ../PulseRate castable as xs:integer and ../GcsMotor castable as xs:integer) then(not(../Sbp = 0 and ../PulseRate = 0 and ../GcsMotor = 1) or not(. ='2')) else(true())">
               <xsl:attribute name="id">6209_DeathInEd</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6209: Field is 2 (Arrived with signs of life) when Initial ED/Hospital SBP = 0, Pulse = 0, AND GCS Motor = 1. Please verify.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M93"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M93"/>
   <xsl:template match="@*|node()" priority="-2" mode="M93">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M93"/>
   </xsl:template>
   <!--PATTERN EdDischargeOrdersWrittenDateEdDischargeOrdersWrittenDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EdDischargeOrdersWrittenDate Assertions</svrl:text>
   <!--RULE EdDischargeOrdersWrittenDate_self_rules-->
   <xsl:template match="EdDischargeOrdersWrittenDate" priority="1000" mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EdDischargeOrdersWrittenDate"
                       id="EdDischargeOrdersWrittenDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6303_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6303: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsNotifyDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsNotifyDate)">
               <xsl:attribute name="id">6304_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6304: ED Discharge Date is earlier than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsArrivalDate)">
               <xsl:attribute name="id">6305_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6305: ED Discharge Date is earlier than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsLeftDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsLeftDate)">
               <xsl:attribute name="id">6306_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6306: ED Discharge Date is earlier than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../HospitalArrivalDate)">
               <xsl:attribute name="id">6307_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6307: ED Discharge Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">6308_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6308: ED Discharge Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">6309_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6309: ED/Hospital Arrival Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or ../HospitalArrivalDate = '' or (fct:durationParse(../HospitalArrivalDate, ., '2') &lt; 365)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or ../HospitalArrivalDate = '' or (fct:durationParse(../HospitalArrivalDate, ., '2') &lt; 365)">
               <xsl:attribute name="id">6310_EdDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6310: ED Discharge Date minus ED/Hospital Arrival Date is greater than 365 days
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M94"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M94"/>
   <xsl:template match="@*|node()" priority="-2" mode="M94">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M94"/>
   </xsl:template>
   <!--PATTERN EdDischargeOrdersWrittenTimeEdDischargeOrdersWrittenTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EdDischargeOrdersWrittenTime Assertions</svrl:text>
   <!--RULE EdDischargeOrdersWrittenTime_self_rules-->
   <xsl:template match="EdDischargeOrdersWrittenTime" priority="1000" mode="M95">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EdDischargeOrdersWrittenTime"
                       id="EdDischargeOrdersWrittenTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6403_EdDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6403: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
               <xsl:attribute name="id">6404_EdDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6404: ED Discharge Time is earlier than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
               <xsl:attribute name="id">6405_EdDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6405: ED Discharge Time is earlier than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)">
               <xsl:attribute name="id">6406_EdDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6406: ED Discharge Time is earlier than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../HospitalArrivalDate) or fct:notLessThanTime(., ../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../HospitalArrivalDate) or fct:notLessThanTime(., ../HospitalArrivalTime)">
               <xsl:attribute name="id">6407_EdDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6407: ED Discharge Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">6408_EdDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6408: ED Discharge Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M95"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M95"/>
   <xsl:template match="@*|node()" priority="-2" mode="M95">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M95"/>
   </xsl:template>
   <!--PATTERN HospitalProcedureIcd10HospitalProcedureIcd10 Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalProcedureIcd10 Assertions</svrl:text>
   <!--RULE HospitalProcedureIcd10_self_rules-->
   <xsl:template match="HospitalProcedureIcd10" priority="1000" mode="M96">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalProcedureIcd10"
                       id="HospitalProcedureIcd10_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8803_HospitalProcedureIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8803: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1') or (every $element in (./following-sibling::*) satisfies ($element=''))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@biu='1') or (every $element in (./following-sibling::*) satisfies ($element=''))">
               <xsl:attribute name="id">8804_HospitalProcedureIcd10</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8804: Field should not be Not Applicable unless patient had no procedures performed
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M96"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M96"/>
   <xsl:template match="@*|node()" priority="-2" mode="M96">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M96"/>
   </xsl:template>
   <!--PATTERN HospitalProcedureStartDateHospitalProcedureStartDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalProcedureStartDate Assertions</svrl:text>
   <!--RULE HospitalProcedureStartDate_self_rules-->
   <xsl:template match="HospitalProcedureStartDate" priority="1000" mode="M97">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalProcedureStartDate"
                       id="HospitalProcedureStartDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6609_HospitalProcedureStartDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6609: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../../../EmsNotifyDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../../../EmsNotifyDate)">
               <xsl:attribute name="id">6603_HospitalProcedureStartDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6603: Hospital Procedure Start Date is earlier than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="., ./../../../EmsArrivalDate"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../../../EmsArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../../../EmsArrivalDate)">
               <xsl:attribute name="id">6604_HospitalProcedureStartDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6604: Hospital Procedure Start Date is earlier than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,./../../../EmsLeftDate"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../../../EmsLeftDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../../../EmsLeftDate)">
               <xsl:attribute name="id">6605_HospitalProcedureStartDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6605: Hospital Procedure Start Date is earlier than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,./../../../HospitalArrivalDate"/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../../../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../../../HospitalArrivalDate)">
               <xsl:attribute name="id">6606_HospitalProcedureStartDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6606: Hospital Procedure Start Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../../../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../../../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">6607_HospitalProcedureStartDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6607: Hospital Procedure Start Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M97"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M97"/>
   <xsl:template match="@*|node()" priority="-2" mode="M97">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M97"/>
   </xsl:template>
   <!--PATTERN HospitalProcedureStartTimeHospitalProcedureStartDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalProcedureStartDate Assertions</svrl:text>
   <!--RULE HospitalProcedureStartTime_self_rules-->
   <xsl:template match="HospitalProcedureStartTime" priority="1000" mode="M98">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalProcedureStartTime"
                       id="HospitalProcedureStartTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6708_HospitalProcedureStartTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6708: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../HospitalProcedureStartDate, ./../../../EmsNotifyDate) or fct:notLessThanTime(., ./../../../EmsNotifyTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../HospitalProcedureStartDate, ./../../../EmsNotifyDate) or fct:notLessThanTime(., ./../../../EmsNotifyTime)">
               <xsl:attribute name="id">6703_HospitalProcedureStartTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6703: Hospital Procedure Start Time is earlier than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../HospitalProcedureStartDate, ./../../../EmsArrivalDate) or fct:notLessThanTime(., ./../../../EmsArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../HospitalProcedureStartDate, ./../../../EmsArrivalDate) or fct:notLessThanTime(., ./../../../EmsArrivalTime)">
               <xsl:attribute name="id">6704_HospitalProcedureStartTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6704: Hospital Procedure Start Time is earlier than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../EmsLeftDate) or fct:notLessThanTime(., ./../../../EmsLeftTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../EmsLeftDate) or fct:notLessThanTime(., ./../../../EmsLeftTime)">
               <xsl:attribute name="id">6705_HospitalProcedureStartTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6705: Hospital Procedure Start Time is earlier than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../HospitalArrivalDate) or fct:notLessThanTime(., ./../../../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../HospitalArrivalDate) or fct:notLessThanTime(., ./../../../HospitalArrivalTime)">
               <xsl:attribute name="id">6706_HospitalProcedureStartTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6706: Hospital Procedure Start Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../../../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../../../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">6707_HospitalProcedureStartTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6707: Hospital Procedure Start Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M98"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M98"/>
   <xsl:template match="@*|node()" priority="-2" mode="M98">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M98"/>
   </xsl:template>
   <!--PATTERN ComorbidConditionComorbidCondition Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ComorbidCondition Assertions</svrl:text>
   <!--RULE ComorbidCondition_self_rules-->
   <xsl:template match="ComorbidCondition" priority="1000" mode="M99">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="ComorbidCondition"
                       id="ComorbidCondition_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">6802_ComorbidCondition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			6802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M99"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M99"/>
   <xsl:template match="@*|node()" priority="-2" mode="M99">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M99"/>
   </xsl:template>
   <!--PATTERN DiagnosisIcd10DiagnosisIcd10 Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">DiagnosisIcd10 Assertions</svrl:text>
   <!--RULE DiagnosisIcd10_self_rules-->
   <xsl:template match="DiagnosisIcd10" priority="1001" mode="M100">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="DiagnosisIcd10"
                       id="DiagnosisIcd10_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8702_DiagnosisIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M100"/>
   </xsl:template>
   <!--RULE DiagnosisIcd10_global_rule-->
   <xsl:template match="TxTdsRecord" priority="1000" mode="M100">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TxTdsRecord"
                       id="DiagnosisIcd10_global_rule"/>
      <xsl:variable name="ntdbElements" select="DiagnosesIcd10/item/DiagnosisIcd10"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="some $element in (DiagnosesIcd10/item/DiagnosisIcd10) satisfies ($element/@biu = '1' or $element != '')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="some $element in (DiagnosesIcd10/item/DiagnosisIcd10) satisfies ($element/@biu = '1' or $element != '')">
               <xsl:attribute name="id">8703_DiagnosisIcd10</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8703: At least one diagnosis must be provided and meet inclusion criteria.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M100"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M100"/>
   <xsl:template match="@*|node()" priority="-2" mode="M100">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M100"/>
   </xsl:template>
   <!--PATTERN AisPredotAisPredot Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AisPredot Assertions</svrl:text>
   <!--RULE AisPredot_self_rules-->
   <xsl:template match="AisPredot" priority="1000" mode="M101">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AisPredot"
                       id="AisPredot_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7007_AisPredot</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7007: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">7008_AisPredot</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7008: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M101"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M101"/>
   <xsl:template match="@*|node()" priority="-2" mode="M101">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M101"/>
   </xsl:template>
   <!--PATTERN AisSeverityAisSeverity Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AisSeverity Assertions</svrl:text>
   <!--RULE AisSeverity_self_rules-->
   <xsl:template match="AisSeverity" priority="1000" mode="M102">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AisSeverity"
                       id="AisSeverity_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7103_AisSeverity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7103: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">7104_AisSeverity</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7104: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M102"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M102"/>
   <xsl:template match="@*|node()" priority="-2" mode="M102">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M102"/>
   </xsl:template>
   <!--PATTERN AisVersionAisVersion Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AisVersion Assertions</svrl:text>
   <!--RULE AisVersion_self_rules-->
   <xsl:template match="AisVersion" priority="1000" mode="M103">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AisVersion"
                       id="AisVersion_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7302_AisVersion</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7302: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">7303_AisVersion</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7303: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M103"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M103"/>
   <xsl:template match="@*|node()" priority="-2" mode="M103">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M103"/>
   </xsl:template>
   <!--PATTERN TotalIcuLosTotalIcuLos Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TotalIcuLos Assertions</svrl:text>
   <!--RULE TotalIcuLos_self_rules-->
   <xsl:template match="TotalIcuLos" priority="1000" mode="M104">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TotalIcuLos"
                       id="TotalIcuLos_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7502_TotalIcuLos</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7502: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="../HospitalArrivalDate ='' or ../HospitalDischargeOrdersWrittenDate ='' or . = '' or . &lt;= fct:durationParse(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate, '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="../HospitalArrivalDate ='' or ../HospitalDischargeOrdersWrittenDate ='' or . = '' or . &lt;= fct:durationParse(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate, '2')">
               <xsl:attribute name="id">7503_TotalIcuLos</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7503: Total ICU Length of Stay is greater than the difference between ED/Hospital Arrival Date and Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 60) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 60) else(true())">
               <xsl:attribute name="id">7504_TotalIcuLos</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7504: Value is greater than 60, please verify this is correct
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M104"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M104"/>
   <xsl:template match="@*|node()" priority="-2" mode="M104">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M104"/>
   </xsl:template>
   <!--PATTERN TotalVentDaysTotalVentDays Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TotalVentDays Assertions</svrl:text>
   <!--RULE TotalVentDays_self_rules-->
   <xsl:template match="TotalVentDays" priority="1000" mode="M105">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TotalVentDays"
                       id="TotalVentDays_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7502_TotalVentDays</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="hospitalArrive" select="fct:parseDate(../HospitalArrivalDate)"/>
      <xsl:variable name="hospitalDischarge"
                    select="fct:parseDate(../HospitalDischargeOrdersWrittenDate)"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="../HospitalArrivalDate ='' or ../HospitalDischargeOrdersWrittenDate ='' or .='' or . &lt;= fct:durationParse(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate, '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="../HospitalArrivalDate ='' or ../HospitalDischargeOrdersWrittenDate ='' or .='' or . &lt;= fct:durationParse(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate, '2')">
               <xsl:attribute name="id">7603_TotalVentDays</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7603: Total Ventilator Days should not be greater than the difference between ED/Hospital Arrival Date and Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt; 60) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt; 60) else(true())">
               <xsl:attribute name="id">7604_TotalVentDays</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7604: Value is greater than 60, please verify this is correct
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M105"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M105"/>
   <xsl:template match="@*|node()" priority="-2" mode="M105">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M105"/>
   </xsl:template>
   <!--PATTERN HospitalDischargeOrdersWrittenDateHospitalDischargeOrdersWrittenDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalDischargeOrdersWrittenDate Assertions</svrl:text>
   <!--RULE HospitalDischargeOrdersWrittenDate_self_rules-->
   <xsl:template match="HospitalDischargeOrdersWrittenDate"
                 priority="1000"
                 mode="M106">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalDischargeOrdersWrittenDate"
                       id="HospitalDischargeOrdersWrittenDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7703_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
		7703: Field cannot be blank
	</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsNotifyDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsNotifyDate)">
               <xsl:attribute name="id">7704_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7704: Hospital Discharge Date is earlier than EMS Dispatch Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsArrivalDate)">
               <xsl:attribute name="id">7705_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7705: Hospital Discharge Date is earlier than EMS Unit Arrival on Scene Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EmsLeftDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EmsLeftDate)">
               <xsl:attribute name="id">7706_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7706: Hospital Discharge Date is earlier than EMS Unit Scene Departure Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../HospitalArrivalDate)">
               <xsl:attribute name="id">7707_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7707: Hospital Discharge Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../EdDischargeOrdersWrittenDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../EdDischargeOrdersWrittenDate)">
               <xsl:attribute name="id">7708_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7708: Hospital Discharge Date is earlier than ED Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ../DateOfBirth)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ../DateOfBirth)">
               <xsl:attribute name="id">7709_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7709: Hospital Discharge Date is earlier than Date of Birth
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or ../IncidentDate = '' or (fct:durationParse(../IncidentDate, ., '2') &lt;= 365)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or ../IncidentDate = '' or (fct:durationParse(../IncidentDate, ., '2') &lt;= 365)">
               <xsl:attribute name="id">7710_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7710: Hospital Discharge Date minus Injury Incident Date is greater than 365 days, please verify this is correct
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test=". = '' or ../HospitalArrivalDate = '' or (fct:durationParse(../HospitalArrivalDate, ., '2') &lt;= 365)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". = '' or ../HospitalArrivalDate = '' or (fct:durationParse(../HospitalArrivalDate, ., '2') &lt;= 365)">
               <xsl:attribute name="id">7711_HospitalDischargeOrdersWrittenDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7711: Hospital Discharge Date minus ED/Hospital Arrival Date is greater than 365 days, please verify this is correct
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../EdDischargeDisposition "/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(../EdDischargeDisposition=('4','5', '6', '9', '10', '11')) or @biu='1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(../EdDischargeDisposition=('4','5', '6', '9', '10', '11')) or @biu='1'">
               <xsl:attribute name="id">7712_HospitalDischargeDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7712: Field must be Not Applicable when ED Discharge Disposition = 4,5,6,9,10, or 11
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M106"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M106"/>
   <xsl:template match="@*|node()" priority="-2" mode="M106">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M106"/>
   </xsl:template>
   <!--PATTERN HospitalDischargeOrdersWrittenTimeHospitalDischargeOrdersWrittenDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalDischargeOrdersWrittenDate Assertions</svrl:text>
   <!--RULE HospitalDischargeOrdersWrittenTime_self_rules-->
   <xsl:template match="HospitalDischargeOrdersWrittenTime"
                 priority="1000"
                 mode="M107">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalDischargeOrdersWrittenTime"
                       id="HospitalDischargeOrdersWrittenTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7803_HospitalDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
		7803: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
               <xsl:attribute name="id">7804_HospitalDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7804: Hospital Discharge Time is earlier than EMS Dispatch Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
               <xsl:attribute name="id">7805_HospitalDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7805: Hospital Discharge Time is earlier than EMS Unit Arrival on Scene Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)">
               <xsl:attribute name="id">7806_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7806: Hospital Discharge Time is earlier than EMS Unit Scene Departure Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../HospitalArrivalDate) or fct:notLessThanTime(., ../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../HospitalArrivalDate) or fct:notLessThanTime(., ../HospitalArrivalTime)">
               <xsl:attribute name="id">7807_HospitalDischargeOrdersWrittenTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7807: Hospital Discharge Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(., ../EdDischargeOrdersWrittenTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(., ../EdDischargeOrdersWrittenTime)">
               <xsl:attribute name="id">7808_IncidentTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7808: Hospital Discharge Time is earlier than ED Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../EdDischargeDisposition "/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(../EdDischargeDisposition=('4','5' ,'6', '9', '10', '11')) or @biu='1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(../EdDischargeDisposition=('4','5' ,'6', '9', '10', '11')) or @biu='1'">
               <xsl:attribute name="id">7809_HospitalPhysicalDischargeTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7809: Field must be Not Applicable when ED Discharge Disposition = 4,5,6,9,10, or 11
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M107"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M107"/>
   <xsl:template match="@*|node()" priority="-2" mode="M107">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M107"/>
   </xsl:template>
   <!--PATTERN HospitalDischargeDispositionHospitalDischargeDisposition Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalDischargeDisposition Assertions</svrl:text>
   <!--RULE HospitalDischargeDisposition_self_rules-->
   <xsl:template match="HospitalDischargeDisposition" priority="1000" mode="M108">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalDischargeDisposition"
                       id="HospitalDischargeDisposition_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">7902_HospitalDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7902: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../EdDischargeDisposition "/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(../EdDischargeDisposition=('4', '6', '9', '10', '11')) or .='' or @biu='1'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(../EdDischargeDisposition=('4', '6', '9', '10', '11')) or .='' or @biu='1'">
               <xsl:attribute name="id">7907_TotalVentDays</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7907: Field must be Not Applicable when ED Discharge Disposition = 4,6,9,10, or 11
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../EdDischargeDisposition "/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1') or ../EdDischargeDisposition=('4', '5', '6', '9', '10', '11')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@biu='1') or ../EdDischargeDisposition=('4', '5', '6', '9', '10', '11')">
               <xsl:attribute name="id">7908_HospitalDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7908: Element cannot be Not Applicable if ED Discharge Disposition is not 4, 5, 6, 9, 10,or 11
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select=".,../EdDischargeDisposition "/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='2') or (../HospitalArrivalDate = '' and ../HospitalDischargeOrdersWrittenDate = '')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@biu='2') or (../HospitalArrivalDate = '' and ../HospitalDischargeOrdersWrittenDate = '')">
               <xsl:attribute name="id">7909_HospitalDischargeDisposition</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			7909: Field cannot be Not Known/Not Recorded when Hospital Arrival Date and Hospital Discharge Date are not: (1) blank, (2) Not Applicable, or (3) Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M108"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M108"/>
   <xsl:template match="@*|node()" priority="-2" mode="M108">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M108"/>
   </xsl:template>
   <!--PATTERN PrimaryMethodPaymentPrimaryMethodPayment Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">PrimaryMethodPayment Assertions</svrl:text>
   <!--RULE PrimaryMethodPayment_self_rules-->
   <xsl:template match="PrimaryMethodPayment" priority="1000" mode="M109">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="PrimaryMethodPayment"
                       id="PrimaryMethodPayment_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8002_PrimaryMethodPayment</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8002: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu='1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu='1')">
               <xsl:attribute name="id">8003_PrimaryMethodPayment</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8003: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M109"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M109"/>
   <xsl:template match="@*|node()" priority="-2" mode="M109">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M109"/>
   </xsl:template>
   <!--PATTERN HospitalComplicationHospitalComplication Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HospitalComplication Assertions</svrl:text>
   <!--RULE HospitalComplication_self_rules-->
   <xsl:template match="HospitalComplication" priority="1000" mode="M110">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HospitalComplication"
                       id="HospitalComplication_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">8102_HospitalComplication</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. = '35') then(../../TotalVentDays != '' or ../../TotalVentDays[@biu] != '1') else (true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. = '35') then(../../TotalVentDays != '' or ../../TotalVentDays[@biu] != '1') else (true())">
               <xsl:attribute name="id">8103_HospitalComplication</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			8103: Hospital Complications include Ventilator Associated Pneumonia although Total Ventilator Days is Not Applicable. Please verify.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M110"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M110"/>
   <xsl:template match="@*|node()" priority="-2" mode="M110">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M110"/>
   </xsl:template>
   <!--PATTERN NationalProviderIdentifierNationalProviderIdentifier Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">NationalProviderIdentifier Assertions</svrl:text>
   <!--RULE NationalProviderIdentifier-->
   <xsl:template match="NationalProviderIdentifier" priority="1000" mode="M111">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="NationalProviderIdentifier"
                       id="NationalProviderIdentifier"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">9802_NationalProviderIdentifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			9802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M111"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M111"/>
   <xsl:template match="@*|node()" priority="-2" mode="M111">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M111"/>
   </xsl:template>
   <!--PATTERN TbiHighestTotalGcsTbiHighestTotalGcs Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiHighestTotalGcs Assertions</svrl:text>
   <!--RULE TbiHighestTotalGcs_self_rules-->
   <xsl:template match="TbiHighestTotalGcs" priority="1000" mode="M112">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiHighestTotalGcs"
                       id="TbiHighestTotalGcs_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10002_TbiHighestTotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10002: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer and ./../TbiGcsMotor castable as xs:integer) then(xs:integer(.) &gt;= xs:integer(./../TbiGcsMotor)) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer and ./../TbiGcsMotor castable as xs:integer) then(xs:integer(.) &gt;= xs:integer(./../TbiGcsMotor)) else(true())">
               <xsl:attribute name="id">10003_TbiHighestTotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10003: Highest GCS Total is less than GCS Motor Component of Highest GCS Total
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="headInjury"
                    select="if(./../AisCodes/item/AisPredot) then(some $element in (./../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
      <xsl:variable name="nextDay"
                    select="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
      <xsl:variable name="ed_discharge_date" select="./../EdDischargePhysicalDate"/>
      <xsl:variable name="hospital_discharge_date"
                    select="./../HospitalPhysicalDischargeDate"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(../TbiGcs40Motor != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../TbiGcs40Motor != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">10006_TbiHighestTotalGcs</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10006: Element must be Not Known/Not Recorded when Highest GCS 40 - Motor is reported.
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M112"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M112"/>
   <xsl:template match="@*|node()" priority="-2" mode="M112">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M112"/>
   </xsl:template>
   <!--PATTERN TbiGcsMotorTbiGcsMotor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiGcsMotor Assertions</svrl:text>
   <!--RULE TbiGcsMotor_self_rules-->
   <xsl:template match="TbiGcsMotor" priority="1000" mode="M113">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiGcsMotor"
                       id="TbiGcsMotor_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10102_TbiGcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(../TbiGcs40Motor != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../TbiGcs40Motor != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">10106_TbiGcsMotor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10106: Field must be Not Known/Not Recorded when Highest GCS 40 - Motor is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="headInjury"
                    select="if(./../AisCodes/item/AisPredot) then(some $element in (./../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
      <xsl:variable name="nextDay"
                    select="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
      <xsl:variable name="ed_discharge_date" select="./../EdDischargePhysicalDate"/>
      <xsl:variable name="hospital_discharge_date"
                    select="./../HospitalPhysicalDischargeDate"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M113"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M113"/>
   <xsl:template match="@*|node()" priority="-2" mode="M113">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M113"/>
   </xsl:template>
   <!--PATTERN TbiGcsQualifierTbiGcsQualifier Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiGcsQualifier Assertions</svrl:text>
   <!--RULE TbiGcsQualifier_self_rules-->
   <xsl:template match="TbiGcsQualifier" priority="1000" mode="M114">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiGcsQualifier"
                       id="TbiGcsQualifier_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10202_TbiGcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10202: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../../../TbiGcs40Motor != '') then(every $element in ./../../item/TbiGcsQualifier satisfies $element/@biu = '2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../../../TbiGcs40Motor != '') then(every $element in ./../../item/TbiGcsQualifier satisfies $element/@biu = '2') else(true())">
               <xsl:attribute name="id">10206_TbiGcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10206: Element must be Not Known/Not Recorded when Highest GCS 40 - Motor is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1','2')) then(every $element in ./../../item/TbiGcsQualifier satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1','2')) then(every $element in ./../../item/TbiGcsQualifier satisfies $element='') else(true())">
               <xsl:attribute name="id">10207_TbiGcsQualifier</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10207: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="headInjury"
                    select="if(./../../../AisCodes/item/AisPredot) then(some $element in (./../../../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
      <xsl:variable name="nextDay"
                    select="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
      <xsl:variable name="ed_discharge_date" select="./../../../EdDischargePhysicalDate"/>
      <xsl:variable name="hospital_discharge_date"
                    select="./../../../HospitalPhysicalDischargeDate"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M114"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M114"/>
   <xsl:template match="@*|node()" priority="-2" mode="M114">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M114"/>
   </xsl:template>
   <!--PATTERN TbiGcs40MotorTbiGcs40Motor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiGcs40Motor Assertions</svrl:text>
   <!--RULE TbiGcs40Motor-->
   <xsl:template match="TbiGcs40Motor" priority="1000" mode="M115">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiGcs40Motor"
                       id="TbiGcs40Motor"/>
      <xsl:variable name="ntdbElements" select="."/>
      <xsl:variable name="headInjury"
                    select="if(./../AisCodes/item/AisPredot) then(some $element in (./../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
      <xsl:variable name="nextDay"
                    select="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
      <xsl:variable name="ed_discharge_date" select="./../EdDischargePhysicalDate"/>
      <xsl:variable name="hospital_discharge_date"
                    select="./../HospitalPhysicalDischargeDate"/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">20602_TbiGcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(../TbiGcsMotor != '') then(@biu='2') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(../TbiGcsMotor != '') then(@biu='2') else(true())">
               <xsl:attribute name="id">20606_TbiGcs40Motor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20606: Element must be Not Known/Not Recorded when Highest GCS - Motor is reported
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M115"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M115"/>
   <xsl:template match="@*|node()" priority="-2" mode="M115">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M115"/>
   </xsl:template>
   <!--PATTERN TbiPupillaryResponseTbiPupillaryResponse Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiPupillaryResponse Assertions</svrl:text>
   <!--RULE TbiPupillaryResponse_self_rules-->
   <xsl:template match="TbiPupillaryResponse" priority="1000" mode="M116">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiPupillaryResponse"
                       id="TbiPupillaryResponse_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">13602_TbiPupillaryResponse</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M116"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M116"/>
   <xsl:template match="@*|node()" priority="-2" mode="M116">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M116"/>
   </xsl:template>
   <!--PATTERN TbiMidlineShiftTbiMidlineShift Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiMidlineShift Assertions</svrl:text>
   <!--RULE TbiMidlineShift_self_rules-->
   <xsl:template match="TbiMidlineShift" priority="1000" mode="M117">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiMidlineShift"
                       id="TbiMidlineShift_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">13702_TbiMidlineShift</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M117"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M117"/>
   <xsl:template match="@*|node()" priority="-2" mode="M117">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M117"/>
   </xsl:template>
   <!--PATTERN TbiCerebralMonitorTbiCerebralMonitor Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiCerebralMonitor Assertions</svrl:text>
   <!--RULE TbiCerebralMonitor_self_rules-->
   <xsl:template match="TbiCerebralMonitor" priority="1000" mode="M118">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiCerebralMonitor"
                       id="TbiCerebralMonitor_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10302_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10302: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1','2')) then(every $element in ./../../item/TbiCerebralMonitor satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1','2')) then(every $element in ./../../item/TbiCerebralMonitor satisfies $element='') else(true())">
               <xsl:attribute name="id">10306_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10306: Element cannot be “Not Applicable” or “Not Known/Not Recorded” along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M118"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M118"/>
   <xsl:template match="@*|node()" priority="-2" mode="M118">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M118"/>
   </xsl:template>
   <!--PATTERN TbiCerebralMonitorDateTbiCerebralMonitorDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiCerebralMonitorDate Assertions</svrl:text>
   <!--RULE TbiCerebralMonitorDate_self_rules-->
   <xsl:template match="TbiCerebralMonitorDate" priority="1000" mode="M119">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiCerebralMonitorDate"
                       id="TbiCerebralMonitorDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10402_TbiCerebralMonitorDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10402: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu = '1') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu = '1') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
               <xsl:attribute name="id">10404_TbiCerebralMonitorDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10404: Field cannot be Not Applicable when Cerebral Monitor is not: (1) blank, (2) Not Applicable, (3) Not Known/Not Recorded, or (4) None
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(@biu = '2') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu = '2') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
               <xsl:attribute name="id">10405_TbiCerebralMonitorDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10405: Field should not be Not Known/Not Recorded when Cerebral Monitor is not: (1) blank, (2) Not Applicable, or (3) Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
               <xsl:attribute name="id">10407_TbiCerebralMonitorDate</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10407: Cerebral Monitor Date should not be earlier than ED/Hospital Arrival Date unless placed at referring facility and used for monitoring
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">10408_TbiCerebralMonitorDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10408: Cerebral Monitor Date should not be later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../TbiCerebralMonitor = '5' or ./../TbiCerebralMonitor/@biu = '1') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../TbiCerebralMonitor = '5' or ./../TbiCerebralMonitor/@biu = '1') then(@biu = '1') else(true())">
               <xsl:attribute name="id">10409_TbiCerebralMonitorDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10409: Field should be Not Applicable when Cerebral Monitor is Not Applicable or None
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M119"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M119"/>
   <xsl:template match="@*|node()" priority="-2" mode="M119">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M119"/>
   </xsl:template>
   <!--PATTERN TbiCerebralMonitorTimeTbiCerebralMonitorTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TbiCerebralMonitorTime Assertions</svrl:text>
   <!--RULE TbiCerebralMonitorTime_self_rules-->
   <xsl:template match="TbiCerebralMonitorTime" priority="1000" mode="M120">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TbiCerebralMonitorTime"
                       id="TbiCerebralMonitorTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10503_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10503: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu = '1') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu = '1') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
               <xsl:attribute name="id">10504_TbiCerebralMonitorTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10504: Field cannot be Not Applicable when Cerebral Monitor is not "Not Applicable" or "Not Known/Not Recorded" or "None"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(@biu = '2') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu = '2') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
               <xsl:attribute name="id">10505_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10505: Field should not be Not Known/Not Recorded when Cerebral Monitor is not "Not Applicable" or "Not Known/Not Recorded"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../TbiCerebralMonitorDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../TbiCerebralMonitorDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
               <xsl:attribute name="id">10506_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10506: Cerebral Monitor Time should not be earlier than ED/Hospital Arrival Time unless placed at referring facility and used for monitoring
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../TbiCerebralMonitorDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../TbiCerebralMonitorDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">10507_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10507: Cerebral Monitor Time should not be later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = '1') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = '1') then(@biu = '1') else(true())">
               <xsl:attribute name="id">10508_TbiCerebralMonitor</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10508: Field should be Not Applicable when Cerebral Monitor is Not Applicable or None
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M120"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M120"/>
   <xsl:template match="@*|node()" priority="-2" mode="M120">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M120"/>
   </xsl:template>
   <!--PATTERN VteProphylaxisTypeVteProphylaxisType Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">VteProphylaxisType Assertions</svrl:text>
   <!--RULE VteProphylaxisType_self_rules-->
   <xsl:template match="VteProphylaxisType" priority="1000" mode="M121">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="VteProphylaxisType"
                       id="VteProphylaxisType_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10602_VteProphylaxisType</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10602: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">10603_VteProphylaxisType</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10603: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M121"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M121"/>
   <xsl:template match="@*|node()" priority="-2" mode="M121">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M121"/>
   </xsl:template>
   <!--PATTERN VteProphylaxisDateVteProphylaxisDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">VteProphylaxisDate Assertions</svrl:text>
   <!--RULE VteProphylaxisDate_self_rules-->
   <xsl:template match="VteProphylaxisDate" priority="1000" mode="M122">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="VteProphylaxisDate"
                       id="VteProphylaxisDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10703_VteProphylaxisDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10703: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu = '1') then(./../VteProphylaxisType = '5' or ./../VteProphylaxisType/@biu = ('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu = '1') then(./../VteProphylaxisType = '5' or ./../VteProphylaxisType/@biu = ('1', '2')) else(true())">
               <xsl:attribute name="id">10705_VteProphylaxisDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10705: Field cannot be Not Applicable when VTE Prophylaxis is not "Not Applicable" or "Not Known/Not Recorded" or "None"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
               <xsl:attribute name="id">10706_VteProphylaxisDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10706: VTE Prophylaxis Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">10707_VteProphylaxisDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10707: VTE Prophylaxis Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../VteProphylaxisType = '5') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../VteProphylaxisType = '5') then(@biu = '1') else(true())">
               <xsl:attribute name="id">10708_VteProphylaxisDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10708: Field should be Not Applicable when VTE Prophylaxis is 'None'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M122"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M122"/>
   <xsl:template match="@*|node()" priority="-2" mode="M122">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M122"/>
   </xsl:template>
   <!--PATTERN VteProphylaxisTimeVteProphylaxisTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">VteProphylaxisTime Assertions</svrl:text>
   <!--RULE VteProphylaxisTime_self_rules-->
   <xsl:template match="VteProphylaxisTime" priority="1000" mode="M123">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="VteProphylaxisTime"
                       id="VteProphylaxisTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10803_VteProphylaxisTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10803: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu = '1') then(./../VteProphylaxisType = '5' or ./../VteProphylaxisType/@biu = ('1', '2')) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu = '1') then(./../VteProphylaxisType = '5' or ./../VteProphylaxisType/@biu = ('1', '2')) else(true())">
               <xsl:attribute name="id">10805_VteProphylaxisTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10805: Field cannot be Not Applicable when Cerebral Monitor is not "Not Applicable" or "Not Known/Not Recorded" or "None"
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../VteProphylaxisDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../VteProphylaxisDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
               <xsl:attribute name="id">10806_VteProphylaxisTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10806: VTE Prophylaxis Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../VteProphylaxisDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../VteProphylaxisDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">10807_VteProphylaxisTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10807: VTE Prophylaxis Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../VteProphylaxisType = '5') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../VteProphylaxisType = '5') then(@biu = '1') else(true())">
               <xsl:attribute name="id">10808_VteProphylaxisTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10808: Field should be Not Applicable when VTE Prophylaxis is 'None'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M123"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M123"/>
   <xsl:template match="@*|node()" priority="-2" mode="M123">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M123"/>
   </xsl:template>
   <!--PATTERN TransfusionBlood4HoursTransfusionBlood4Hours Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TransfusionBlood4Hours Assertions</svrl:text>
   <!--RULE TransfusionBlood4Hours_self_rules-->
   <xsl:template match="TransfusionBlood4Hours" priority="1000" mode="M124">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TransfusionBlood4Hours"
                       id="TransfusionBlood4Hours_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">21802_TransfusionBlood4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">21803_TransfusionBlood4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21803: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
               <xsl:attribute name="id">21804_TransfusionBlood4Hours</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21804: Value exceeds 40,000 for CCs
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M124"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M124"/>
   <xsl:template match="@*|node()" priority="-2" mode="M124">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M124"/>
   </xsl:template>
   <!--PATTERN WholeBlood4HoursWholeBlood4Hours Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">WholeBlood4Hours Assertions</svrl:text>
   <!--RULE WholeBlood4Hours_self_rules-->
   <xsl:template match="WholeBlood4Hours" priority="1000" mode="M125">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="WholeBlood4Hours"
                       id="WholeBlood4Hours_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">21102_WholeBlood4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">21103_WholeBlood4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21103: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
               <xsl:attribute name="id">21104_WholeBlood4Hours</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21104: Value exceeds 40,000 for CCs
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M125"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M125"/>
   <xsl:template match="@*|node()" priority="-2" mode="M125">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M125"/>
   </xsl:template>
   <!--PATTERN TransfusionPlasma4HoursTransfusionPlasma4Hours Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TransfusionPlasma4Hours Assertions</svrl:text>
   <!--RULE TransfusionPlasma4Hours_self_rules-->
   <xsl:template match="TransfusionPlasma4Hours" priority="1000" mode="M126">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TransfusionPlasma4Hours"
                       id="TransfusionPlasma4Hours_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">21202_TransfusionPlasma4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21202: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
               <xsl:attribute name="id">11104_TransfusionPlasma4Hours</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21204: Value exceeds 40,000 for CCs
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">21208_TransfusionPlasma4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21208: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M126"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M126"/>
   <xsl:template match="@*|node()" priority="-2" mode="M126">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M126"/>
   </xsl:template>
   <!--PATTERN TransfusionPlatelets4HoursTransfusionPlatelets4Hours Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">TransfusionPlatelets4Hours Assertions</svrl:text>
   <!--RULE TransfusionPlatelets4Hours_self_rules-->
   <xsl:template match="TransfusionPlatelets4Hours" priority="1000" mode="M127">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="TransfusionPlatelets4Hours"
                       id="TransfusionPlatelets4Hours_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">21302_TransfusionPlatelets4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21302: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
               <xsl:attribute name="id">21304_TransfusionPlatelets4Hours</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21304: Value exceeds 40,000 for CCs
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">21308_TransfusionPlasma4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21308: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M127"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M127"/>
   <xsl:template match="@*|node()" priority="-2" mode="M127">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M127"/>
   </xsl:template>
   <!--PATTERN Cryoprecipitate4HoursCryoprecipitate4Hours Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Cryoprecipitate4Hours Assertions</svrl:text>
   <!--RULE Cryoprecipitate4Hours_self_rules-->
   <xsl:template match="Cryoprecipitate4Hours" priority="1000" mode="M128">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Cryoprecipitate4Hours"
                       id="Cryoprecipitate4Hours_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">21402_Cryoprecipitate4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21402: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
               <xsl:attribute name="id">11304_Cryoprecipitate4Hours</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21404: Value exceeds 40,000 for CCs
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">21408_Cryoprecipitate4Hours</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			21408: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M128"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M128"/>
   <xsl:template match="@*|node()" priority="-2" mode="M128">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M128"/>
   </xsl:template>
   <!--PATTERN LowestSbpLowestSbp Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">LowestSbp Assertions</svrl:text>
   <!--RULE LowestSbp_self_rules-->
   <xsl:template match="LowestSbp" priority="1000" mode="M129">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="LowestSbp"
                       id="LowestSbp_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">10902_LowestSbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10902: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &lt;= 220) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &lt;= 220) else(true())">
               <xsl:attribute name="id">10903_LowestSbp</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10903: The value is above 220
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true())">
               <xsl:attribute name="id">10905_LowestSbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10905: Element cannot be Not Applicable when Packed Red Blood Cells or Whole Blood is greater than 0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true())">
               <xsl:attribute name="id">10906_LowestSbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10906: Element must be Not Applicable when Packed Red Blood Cells and Whole Blood are 0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true())">
               <xsl:attribute name="id">10907_LowestSbp</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10907: Element must be Not Known/Not Recorded when Packed Red Blood Cells and Whole Blood are Not Known/Not Recorded
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [WARNING]-->
      <xsl:choose>
         <xsl:when test="if(. castable as xs:integer) then(. &gt;= 30) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(. castable as xs:integer) then(. &gt;= 30) else(true())">
               <xsl:attribute name="id">10909_LowestSbp</xsl:attribute>
               <xsl:attribute name="role">[WARNING]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			10909: Warning: SBP value below 30
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M129"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M129"/>
   <xsl:template match="@*|node()" priority="-2" mode="M129">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M129"/>
   </xsl:template>
   <!--PATTERN AngiographyAngiography Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Angiography Assertions</svrl:text>
   <!--RULE Angiography_self_rules-->
   <xsl:template match="Angiography" priority="1000" mode="M130">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="Angiography"
                       id="Angiography_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">11702_Angiography</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true())">
               <xsl:attribute name="id">11703_Angiography</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11703: Element cannot be Not Applicable when Packed Red Blood Cells or Whole Blood is greater than 0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true())">
               <xsl:attribute name="id">11704_Angiography</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11704: Element must be Not Applicable when Packed Red Blood Cells and Whole Blood are 0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true())">
               <xsl:attribute name="id">11705_Angiography</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11705: Element must be Not Known/Not Recorded when Packed Red Blood Cells and Whole Blood are “Not Known/Not Recorded”
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M130"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M130"/>
   <xsl:template match="@*|node()" priority="-2" mode="M130">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M130"/>
   </xsl:template>
   <!--PATTERN EmbolizationSiteEmbolizationSite Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">EmbolizationSite Assertions</svrl:text>
   <!--RULE EmbolizationSite_self_rules-->
   <xsl:template match="EmbolizationSite" priority="1000" mode="M131">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="EmbolizationSite"
                       id="EmbolizationSite_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">11802_EmbolizationSite</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Angiography = '3' and . = '') then(@biu != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Angiography = '3' and . = '') then(@biu != '1') else(true())">
               <xsl:attribute name="id">11803_EmbolizationSite</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11803: Field cannot be Not Applicable when Angiography is 'Angiogram with embolization'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../../../Angiography = ('1', '2','4')) then(every $element in ./../../item/EmbolizationSite satisfies $element/@biu='1') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../../../Angiography = ('1', '2','4')) then(every $element in ./../../item/EmbolizationSite satisfies $element/@biu='1') else(true())">
               <xsl:attribute name="id">11804_EmbolizationSite</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11804: Field should be Not Applicable when Angiography is 'None' or 'Angiogram only', or 'Angiogram with stenting'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu=('1','2')) then(every $element in ./../../item/EmbolizationSite satisfies $element='') else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu=('1','2')) then(every $element in ./../../item/EmbolizationSite satisfies $element='') else(true())">
               <xsl:attribute name="id">11805_EmbolizationSite</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11805: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M131"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M131"/>
   <xsl:template match="@*|node()" priority="-2" mode="M131">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M131"/>
   </xsl:template>
   <!--PATTERN AngiographyDateAngiographyDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AngiographyDate Assertions</svrl:text>
   <!--RULE AngiographyDate_self_rules-->
   <xsl:template match="AngiographyDate" priority="1000" mode="M132">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AngiographyDate"
                       id="AngiographyDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">11903_AngiographyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11903: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Angiography = ('2', '3','4') and . = '') then(@biu != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Angiography = ('2', '3','4') and . = '') then(@biu != '1') else(true())">
               <xsl:attribute name="id">11904_EmbolizationSite</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11904: Field cannot be Not Applicable when Angiography is 'Angiogram only' or 'Angiogram with embolization' or 'Angiogram with stenting'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Angiography = '1') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Angiography = '1') then(@biu = '1') else(true())">
               <xsl:attribute name="id">11905_EmbolizationSite</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11905: Field should be Not Applicable when Angiography is 'None'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
               <xsl:attribute name="id">11906_AngiographyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11906: Angiography Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">11907_AngiographyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11907: Angiography Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(fct:notLessThanDate(., ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ., '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ., '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, ./../AngiographyTime)) else(fct:durationParse(./../HospitalArrivalDate, ., '2') = 0)) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(fct:notLessThanDate(., ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ., '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ., '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, ./../AngiographyTime)) else(fct:durationParse(./../HospitalArrivalDate, ., '2') = 0)) else(true())">
               <xsl:attribute name="id">11908_AngiographyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			11908: Angiography Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M132"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M132"/>
   <xsl:template match="@*|node()" priority="-2" mode="M132">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M132"/>
   </xsl:template>
   <!--PATTERN AngiographyTimeAngiographyTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AngiographyTime Assertions</svrl:text>
   <!--RULE AngiographyTime_self_rules-->
   <xsl:template match="AngiographyTime" priority="1000" mode="M133">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AngiographyTime"
                       id="AngiographyTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">12003_AngiographyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12003: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Angiography = ('2', '3','4') and . = '') then(@biu != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Angiography = ('2', '3','4') and . = '') then(@biu != '1') else(true())">
               <xsl:attribute name="id">12004_AngiographyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12004: Field cannot be Not Applicable when Angiography is 'Angiogram only' or 'Angiogram with embolization' or 'Angiogram with stenting'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../Angiography = '1') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../Angiography = '1') then(@biu = '1') else(true())">
               <xsl:attribute name="id">12005_AngiographyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12005: Field should be Not Applicable when Angiography is 'None'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../AngiographyDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../AngiographyDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
               <xsl:attribute name="id">12006_AngiographyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12006: Angiography Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../AngiographyDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../AngiographyDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">12007_AngiographyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12007: Angiography Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(fct:notLessThanDate(./../AngiographyDate, ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, .)) else(fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') = 0)) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(fct:notLessThanDate(./../AngiographyDate, ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, .)) else(fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') = 0)) else(true())">
               <xsl:attribute name="id">12008_AngiographyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12008: Angiography Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M133"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M133"/>
   <xsl:template match="@*|node()" priority="-2" mode="M133">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M133"/>
   </xsl:template>
   <!--PATTERN HemorrhageControlSurgeryTypeHemorrhageControlSurgeryType Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HemorrhageControlSurgeryType Assertions</svrl:text>
   <!--RULE HemorrhageControlSurgeryType_self_rules-->
   <xsl:template match="HemorrhageControlSurgeryType" priority="1000" mode="M134">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HemorrhageControlSurgeryType"
                       id="HemorrhageControlSurgeryType_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">12102_HemorrhageControlSurgeryType</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12102: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true())">
               <xsl:attribute name="id">12103_HemorrhageControlSurgeryType</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12103: Element cannot be Not Applicable when Packed Red Blood Cells or Whole Blood is greater than 0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true())">
               <xsl:attribute name="id">12104_HemorrhageControlSurgeryType</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12104: Element must be Not Applicable when Packed Red Blood Cells and Whole Blood are 0
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true())">
               <xsl:attribute name="id">12105_HemorrhageControlSurgeryType</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12105: Element must be Not Known/Not Recorded when Packed Red Blood Cells and Whole Blood are “Not Known/Not Recorded”
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M134"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M134"/>
   <xsl:template match="@*|node()" priority="-2" mode="M134">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M134"/>
   </xsl:template>
   <!--PATTERN HemorrhageControlSurgeryDateHemorrhageControlSurgeryDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HemorrhageControlSurgeryDate Assertions</svrl:text>
   <!--RULE HemorrhageControlSurgeryDate_self_rules-->
   <xsl:template match="HemorrhageControlSurgeryDate" priority="1000" mode="M135">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HemorrhageControlSurgeryDate"
                       id="HemorrhageControlSurgeryDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
               <xsl:attribute name="id">12203_HemorrhageControlSurgeryDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12203: Surgery For Hemorrhage Control Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">12204_HemorrhageControlSurgeryDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12204: Surgery For Hemorrhage Control Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='1') then(./../HemorrhageControlSurgeryType = '1' or ./../HemorrhageControlSurgeryType = '') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='1') then(./../HemorrhageControlSurgeryType = '1' or ./../HemorrhageControlSurgeryType = '') else(true())">
               <xsl:attribute name="id">12205_HemorrhageControlSurgeryDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12205: Field cannot be Not Applicable when Hemorrhage Control Surgery Type is not: (1) blank, (2) Not Applicable, (3) Not Known/Not Recorded or (4) None
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HemorrhageControlSurgeryType = '1') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HemorrhageControlSurgeryType = '1') then(@biu = '1') else(true())">
               <xsl:attribute name="id">12206_HemorrhageControlSurgeryDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12206: Field should be Not Applicable when Hemorrhage Control Surgery Type is 'None'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">12207_HemorrhageControlSurgeryDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12207: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(fct:notLessThanDate(., ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ., '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ., '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, ./../HemorrhageControlSurgeryTime)) else(fct:durationParse(./../HospitalArrivalDate, ., '2') = 0)) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(fct:notLessThanDate(., ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ., '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ., '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, ./../HemorrhageControlSurgeryTime)) else(fct:durationParse(./../HospitalArrivalDate, ., '2') = 0)) else(true())">
               <xsl:attribute name="id">12208_HemorrhageControlSurgeryDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12208: Surgery for Hemorrhage Control Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M135"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M135"/>
   <xsl:template match="@*|node()" priority="-2" mode="M135">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M135"/>
   </xsl:template>
   <!--PATTERN HemorrhageControlSurgeryTimeHemorrhageControlSurgeryTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">HemorrhageControlSurgeryTime Assertions</svrl:text>
   <!--RULE HemorrhageControlSurgeryTime_self_rules-->
   <xsl:template match="HemorrhageControlSurgeryTime" priority="1000" mode="M136">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="HemorrhageControlSurgeryTime"
                       id="HemorrhageControlSurgeryTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../HemorrhageControlSurgeryDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../HemorrhageControlSurgeryDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
               <xsl:attribute name="id">12303_HemorrhageControlSurgeryTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12303: Surgery For Hemorrhage Control Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../HemorrhageControlSurgeryDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../HemorrhageControlSurgeryDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">12304_HemorrhageControlSurgeryTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12304: Surgery For Hemorrhage Control Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='1') then(./../HemorrhageControlSurgeryType = '1' or ./../HemorrhageControlSurgeryType = '') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='1') then(./../HemorrhageControlSurgeryType = '1' or ./../HemorrhageControlSurgeryType = '') else(true())">
               <xsl:attribute name="id">12305_HemorrhageControlSurgeryTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12305: Field cannot be Not Applicable when Hemorrhage Control Surgery Type is not: (1) blank, (2) Not Applicable, (3) Not Known/Not Recorded or (4) None
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../HemorrhageControlSurgeryType = '1') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../HemorrhageControlSurgeryType = '1') then(@biu = '1') else(true())">
               <xsl:attribute name="id">12306_HemorrhageControlSurgeryTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12306: Field should be Not Applicable when Hemorrhage Control Surgery Type is 'None'
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">12307_HemorrhageControlSurgeryTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12307: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(fct:notLessThanDate(./../HemorrhageControlSurgeryDate, ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, .)) else(fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') = 0)) else(true())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(fct:notLessThanDate(./../HemorrhageControlSurgeryDate, ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, .)) else(fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') = 0)) else(true())">
               <xsl:attribute name="id">12308_HemorrhageControlSurgeryTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			12308: Surgery for Hemorrhage Control Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M136"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M136"/>
   <xsl:template match="@*|node()" priority="-2" mode="M136">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M136"/>
   </xsl:template>
   <!--PATTERN WithdrawalOfCareWithdrawalOfCare Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">WithdrawalOfCare Assertions</svrl:text>
   <!--RULE WithdrawalOfCare_self_rules-->
   <xsl:template match="WithdrawalOfCare" priority="1000" mode="M137">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="WithdrawalOfCare"
                       id="WithdrawalOfCare_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">13802_WithdrawalOfCare</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13802: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="not(@biu=('1'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@biu=('1'))">
               <xsl:attribute name="id">13803_WithdrawalOfCare</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13803: Field cannot be Not Applicable
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M137"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M137"/>
   <xsl:template match="@*|node()" priority="-2" mode="M137">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M137"/>
   </xsl:template>
   <!--PATTERN WithdrawalOfCareDateWithdrawalOfCareDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">WithdrawalOfCareDate Assertions</svrl:text>
   <!--RULE WithdrawalOfCareDate_self_rules-->
   <xsl:template match="WithdrawalOfLifeSupportingTreatmentDate"
                 priority="1000"
                 mode="M138">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="WithdrawalOfLifeSupportingTreatmentDate"
                       id="WithdrawalOfCareDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(., ./../HospitalArrivalDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
               <xsl:attribute name="id">13903_WithdrawalOfCareDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13903: Withdrawal of Life Supporting Treatment Date is earlier than ED/Hospital Arrival Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">13904_WithdrawalOfCareDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13904: Withdrawal of Life Supporting Treatment Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='1') then(./../WithdrawalOfLifeSupportingTreatment != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='1') then(./../WithdrawalOfLifeSupportingTreatment != '1') else(true())">
               <xsl:attribute name="id">13905_WithdrawalOfCareDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13905: Field cannot be Not Applicable when Withdrawal of Life Supporting Treatment is 1 (Yes)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../WithdrawalOfLifeSupportingTreatment = '2') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../WithdrawalOfLifeSupportingTreatment = '2') then(@biu = '1') else(true())">
               <xsl:attribute name="id">13906_WithdrawalOfCareDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13906: Field should be Not Applicable when Withdrawal of Life Supporting Treatment is 2 (No)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">13907_WithdrawalOfCareDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			13907: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M138"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M138"/>
   <xsl:template match="@*|node()" priority="-2" mode="M138">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M138"/>
   </xsl:template>
   <!--PATTERN WithdrawalOfCareTimeWithdrawalOfCareTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">WithdrawalOfCareTime Assertions</svrl:text>
   <!--RULE WithdrawalOfCareTime_self_rules-->
   <xsl:template match="WithdrawalOfCareTime" priority="1000" mode="M139">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="WithdrawalOfCareTime"
                       id="WithdrawalOfCareTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../WithdrawalOfLifeSupportingTreatmentDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../WithdrawalOfLifeSupportingTreatmentDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
               <xsl:attribute name="id">14003_WithdrawalOfCareTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			14003: Withdrawal of Life Supporting Treatment Time is earlier than ED/Hospital Arrival Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../WithdrawalOfLifeSupportingTreatmentDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../WithdrawalOfLifeSupportingTreatmentDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">14004_WithdrawalOfCareTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			14004: Withdrawal of Life Supporting Treatment Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='1') then(./../WithdrawalOfLifeSupportingTreatment != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='1') then(./../WithdrawalOfLifeSupportingTreatment != '1') else(true())">
               <xsl:attribute name="id">14005_WithdrawalOfCareTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			14005: Field cannot be Not Applicable when Withdrawal of Life Supporting Treatment is 1 (Yes)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../WithdrawalOfLifeSupportingTreatment = '2') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../WithdrawalOfLifeSupportingTreatment = '2') then(@biu = '1') else(true())">
               <xsl:attribute name="id">14006_WithdrawalOfCareTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			14006: Field should be Not Applicable when Withdrawal of Life Supporting Treatment is 2 (No)
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">14007_WithdrawalOfCareTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			14007: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M139"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M139"/>
   <xsl:template match="@*|node()" priority="-2" mode="M139">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M139"/>
   </xsl:template>
   <!--PATTERN AntibioticTherapyAntibioticTherapy Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AntibioticTherapy Assertions</svrl:text>
   <!--RULE AntibioticTherapy_self_rules-->
   <xsl:template match="AntibioticTherapy" priority="1000" mode="M140">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AntibioticTherapy"
                       id="AntibioticTherapy_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test=". != '' or @biu=('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=". != '' or @biu=('1', '2')">
               <xsl:attribute name="id">20702_AntibioticTherapy</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20702: Field cannot be blank
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M140"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M140"/>
   <xsl:template match="@*|node()" priority="-2" mode="M140">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M140"/>
   </xsl:template>
   <!--PATTERN AntibioticTherapyDateAntibioticTherapyDate Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AntibioticTherapyDate Assertions</svrl:text>
   <!--RULE AntibioticTherapyDate_self_rules-->
   <xsl:template match="AntibioticTherapyDate" priority="1000" mode="M141">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AntibioticTherapyDate"
                       id="AntibioticTherapyDate_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
               <xsl:attribute name="id">20807_AntibioticTherapyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20807: Antibiotic Therapy Date is later than Hospital Discharge Date
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='1') then(./../AntibioticTherapy != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='1') then(./../AntibioticTherapy != '1') else(true())">
               <xsl:attribute name="id">20803_AntibioticTherapyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20903: Element cannot be Not Applicable when Antibiotic Therapy is 1. Yes
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../AntibioticTherapy = '2') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../AntibioticTherapy = '2') then(@biu = '1') else(true())">
               <xsl:attribute name="id">20804_AntibioticTherapyDate</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20804: Element must be Not Applicable when Antibiotic Therapy is 2. No
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M141"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M141"/>
   <xsl:template match="@*|node()" priority="-2" mode="M141">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M141"/>
   </xsl:template>
   <!--PATTERN AntibioticTherapyTimeAntibioticTherapyTime Assertions-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">AntibioticTherapyTime Assertions</svrl:text>
   <!--RULE AntibioticTherapyTime_self_rules-->
   <xsl:template match="AntibioticTherapyTime" priority="1000" mode="M142">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="AntibioticTherapyTime"
                       id="AntibioticTherapyTime_self_rules"/>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="fct:notEqualDate(./../AntibioticTherapyDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fct:notEqualDate(./../AntibioticTherapyDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
               <xsl:attribute name="id">20907_AntibioticTherapyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20907: Antibiotic Therapy Time is later than Hospital Discharge Time
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="ntdbElements" select="."/>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(@biu='1') then(./../AntibioticTherapy != '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(@biu='1') then(./../AntibioticTherapy != '1') else(true())">
               <xsl:attribute name="id">20903_AntibioticTherapyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20903: Element cannot be Not Applicable when Antibiotic Therapy is 1. Yes
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT [ERROR]-->
      <xsl:choose>
         <xsl:when test="if(./../AntibioticTherapy = '2') then(@biu = '1') else(true()) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if(./../AntibioticTherapy = '2') then(@biu = '1') else(true())">
               <xsl:attribute name="id">20904_AntibioticTherapyTime</xsl:attribute>
               <xsl:attribute name="role">[ERROR]</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
			20904: Element must be Not Applicable when Antibiotic Therapy is 2. No
		</svrl:text>
               <svrl:diagnostic-reference diagnostic="ntdbDiagnostic">
                  <ntdbDiagnostic xmlns:sch="http://purl.oclc.org/dsdl/schematron">
                     <record>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
                        <xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
                     </record>
                     <elements>
                        <xsl:for-each select="$ntdbElements">
                           <xsl:element name="element">
                              <xsl:attribute name="location">
                                 <xsl:apply-templates select="." mode="schematron-get-full-path"/>
                              </xsl:attribute>
                              <xsl:for-each select="@*">
                                 <xsl:attribute name="{name()}">
                                    <xsl:value-of select="."/>
                                 </xsl:attribute>
                              </xsl:for-each>
                              <xsl:if test="not(*)">
                                 <xsl:value-of select="."/>
                              </xsl:if>
                           </xsl:element>
                        </xsl:for-each>
                     </elements>
                  </ntdbDiagnostic>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M142"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M142"/>
   <xsl:template match="@*|node()" priority="-2" mode="M142">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M142"/>
   </xsl:template>
</xsl:stylesheet>
